const AWS = require('aws-sdk');
const proxy = require('proxy-agent');
const { SQS_DEFAULT_REGION, PUT_LOGS_ARN } = require('../consts');
const getLogger = require('../logger/logger');

const logger = getLogger();

async function getAwsAccountId() {
    let httpOptions;
    if (process.env.http_proxy) {
        httpOptions = {
            agent: proxy(process.env.http_proxy)
        };
    }

    const sts = new AWS.STS({ region: SQS_DEFAULT_REGION, httpOptions });
    try {
        const callerIdentity = await sts.getCallerIdentity({}).promise();
        return callerIdentity.Account;
    } catch (err) {
        logger.warn('AWS Caller identity is not available');
    }
}

async function assumeRole(accessKey, secretKey, roleSessionName) {
    let httpOptions;

    if (process.env.http_proxy) {
        httpOptions = {
            agent: proxy(process.env.http_proxy)
        };
    }

    const sts = new AWS.STS({
        region: SQS_DEFAULT_REGION,
        accessKeyId: accessKey,
        secretAccessKey: secretKey,
        httpOptions
    });
    const result = await sts.assumeRole({ RoleArn: PUT_LOGS_ARN, RoleSessionName: roleSessionName }).promise();
    return result.Credentials;
}

module.exports = { getAwsAccountId, assumeRole };
