const axios = require('axios');

async function getMetadata(url) {
    const { data } = await axios.get(url, { headers: { Metadata: true } });
    return data;
}

async function getAzureMetadata() {
    const [{ publicIpAddress }, { address, prefix }, {
        vmId, location, resourceGroupName
    }] = await Promise.all([
        getMetadata('http://169.254.169.254/metadata/instance/network/interface/0/ipv4/ipAddress/0/?api-version=2017-08-01'),
        getMetadata('http://169.254.169.254/metadata/instance/network/interface/0/ipv4/subnet/0/?api-version=2017-08-01'),
        getMetadata('http://169.254.169.254/metadata/instance/compute/?api-version=2017-08-01')
    ]);

    return {
        instanceId: vmId,
        publicIp: publicIpAddress,
        region: location,
        resourceGroupName,
        subnetCidrBlock: `${address}/${prefix}`
    };
}

module.exports = getAzureMetadata;
