const gcpMetadata = require('gcp-metadata');
const { last } = require('lodash');
const getLogger = require('../logger/logger');

const logger = getLogger();

async function getGcpMetadata() {
    const [instanceId, serviceAccount, network, subnetCidrBlock, zone] = await Promise.all([gcpMetadata.instance('id'), gcpMetadata.instance('service-accounts'), gcpMetadata.instance('network-interfaces/0/network'), gcpMetadata.instance('network-interfaces/0/subnetmask'), gcpMetadata.instance('zone')]);

    const gcpMetadataObj = {
        instanceId: instanceId.toString(),
        serviceAccount: serviceAccount.replace('\n', '').trim(),
        network: last(network.split('/')),
        subnetCidrBlock,
        zone: last(zone.split('/'))
    };

    try {
        gcpMetadataObj.publicIp = await gcpMetadata.instance('network-interfaces/0/access-configs/0/external-ip');
    } catch (err) {
        logger.warn('Couldn\'t get public IP of GCP databroker: ', err);
    }

    return gcpMetadataObj;
}

module.exports = getGcpMetadata;
