const Joi = require('@hapi/joi');
const {
    IPC_TYPE_COPY, IPC_TYPE_DONE, IPC_TYPE_REMOVE, IPC_TYPE_ABORT, IPC_TYPE_UPDATE
} = require('../../lib/consts');
const settingsSchema = require('../schemas/settings-schema');

const scannerIncomingIPCCopySchema = Joi.object().keys({
    transferrerQueue: Joi.string().required(),
    scannerQueue: Joi.string().required(),
    relationshipId: Joi.string().required(),
    requestId: Joi.string().required(),
    type: Joi.string().valid(IPC_TYPE_COPY).required(),
    settings: settingsSchema.required(),
    serverName: Joi.string(),
    certificate: Joi.string()
});

const scannerIncomingIPCDoneRemoveAbortSchema = Joi.object().keys({
    type: Joi.string().valid(IPC_TYPE_DONE, IPC_TYPE_REMOVE, IPC_TYPE_ABORT, IPC_TYPE_UPDATE).required(),
    relationshipId: Joi.string().required(),
    source: Joi.string().required(),
    target: Joi.string().required()
});

const scannerIncomingIPCCreateScannerSchema = Joi.object().keys({
    type: Joi.string().valid('create-scanner').required(),
    workerId: Joi.number().integer().min(0).required()
});

const scannerIncomingIPCMessagesSchemes = {
    copy: scannerIncomingIPCCopySchema,
    remove: scannerIncomingIPCDoneRemoveAbortSchema,
    abort: scannerIncomingIPCDoneRemoveAbortSchema,
    done: scannerIncomingIPCDoneRemoveAbortSchema,
    update: scannerIncomingIPCDoneRemoveAbortSchema,
    'create-scanner': scannerIncomingIPCCreateScannerSchema
};

module.exports = scannerIncomingIPCMessagesSchemes;
