const Joi = require('@hapi/joi');
const {
    ONTAP_S3_PROVIDER,
    NFS_VERSIONS, CIFS_VERSIONS, ALIBABA_PROVIDER, S3_PROVIDER, SGWS_PROVIDER, IBM_PROVIDER
} = require('../../lib/consts');

const deepArchiveObject = Joi.object().keys({
    days: Joi.number().integer().required(),
    tier: Joi.string().required().valid('Standard', 'Bulk')
});

const glacierObject = Joi.object().keys({
    days: Joi.number().integer().required(),
    tier: Joi.string().required().valid('Expedited', 'Standard', 'Bulk')
});

const endPointSchema = Joi.object().keys({
    cifs: Joi.object().keys({
        host: Joi.string().required(),
        share: Joi.string().required(),
        path: Joi.string(),
        username: Joi.string(),
        password: Joi.string(),
        workgroup: Joi.string(),
        version: Joi.number().valid(...CIFS_VERSIONS).label('version'),
        aclServer: Joi.string()
    }),
    nfs: Joi.object().keys({
        host: Joi.string().required(),
        export: Joi.string().required(),
        path: Joi.string(),
        version: Joi.number().valid(...NFS_VERSIONS).label('version')
    }),
    snfs: Joi.object().keys({
        serverIP: Joi.string().required(),
        host: Joi.string().required(),
        export: Joi.string().required(),
        path: Joi.string(),
        version: Joi.number().valid(...NFS_VERSIONS)
    }),
    local: Joi.object().keys({ path: Joi.string().required() }),
    efs: Joi.object().keys({
        host: Joi.string().required(),
        export: Joi.string().required(),
        path: Joi.string()
    }),
    s3: Joi.object().keys({
        region: Joi.string(),
        bucket: Joi.string().required(),
        path: Joi.string().allow(''),
        storageClass: Joi.string().valid('STANDARD', 'STANDARD_IA', 'ONEZONE_IA', 'INTELLIGENT_TIERING', 'GLACIER', 'DEEP_ARCHIVE'),
        encryption: Joi.object().keys({
            kms: Joi.object().keys({
                keyId: Joi.string().required()
            })
        }),
        provider: Joi.string().valid(ONTAP_S3_PROVIDER, ALIBABA_PROVIDER, S3_PROVIDER, SGWS_PROVIDER, IBM_PROVIDER),
        tags: Joi.array().items(Joi.object().keys({
            Key: Joi.string().required(),
            Value: Joi.string().required()
        })),
        accessKey: Joi.string(),
        secretKey: Joi.string(),
        host: Joi.when('provider', { is: [SGWS_PROVIDER, IBM_PROVIDER], then: Joi.string().required() }),
        port: Joi.when('provider', { is: [IBM_PROVIDER], then: Joi.string().required() }),
        glacier: glacierObject,
        deepArchive: deepArchiveObject
    }),
    azure: Joi.object().keys({
        container: Joi.string().required(),
        storageAccountName: Joi.string().required(),
        storageAccountConnectionString: Joi.string(),
        path: Joi.string(),
        tags: Joi.array().items(Joi.object().keys({
            Key: Joi.string().required(),
            Value: Joi.string().required()
        })),
        blobTier: Joi.string().valid('HOT', 'COOL', 'ARCHIVE')
    }),
    gcp: Joi.object().keys({
        bucket: Joi.string().required(),
        path: Joi.string().allow(''),
        tags: Joi.array().items(Joi.object().keys({
            Key: Joi.string().required(),
            Value: Joi.string().required()
        }))
    })
}).xor('cifs', 'nfs', 'efs', 's3', 'local', 'azure', 'gcp', 'snfs');

module.exports = endPointSchema;
