const Joi = require('@hapi/joi');

const typesSchema = Joi.object().keys({
    files: Joi.boolean().required(),
    directories: Joi.boolean().required(),
    symlinks: Joi.boolean().required()
});

const filesSchema = Joi.object().keys({
    excludeExtensions: Joi.array().items(Joi.string().regex(/^\./, { name: 'extensions' })).unique().max(15)
        .required(),
    minSize: Joi.number().integer().min(0).max(Number.MAX_SAFE_INTEGER)
        .required(),
    maxSize: Joi.number().integer().min(0).max(Number.MAX_SAFE_INTEGER)
        .required(),
    minDate: Joi.date().iso().min('1970-01-01').required(),
    maxDate: Joi.date().iso().min('1970-01-01').allow(null)
});

const settingsSchema = Joi.object().keys({
    gracePeriod: Joi.number().min(0).required(),
    deleteOnSource: Joi.boolean().required(),
    deleteOnTarget: Joi.boolean().required().when('deleteOnSource', { // We don't want both of them to be true, o.w all the data wil be deleted on second sync
        is: true,
        then: Joi.valid(false)
    }),
    objectTagging: Joi.boolean().required(),
    retries: Joi.number().integer().min(0).max(5)
        .required(),
    copyAcl: Joi.alternatives().try(Joi.boolean(), Joi.string()).required(),
    files: filesSchema.required(),
    fileTypes: typesSchema.required()
});

module.exports = settingsSchema;
