const Joi = require('@hapi/joi');
const http2 = require('http2');

const {
    HTTP2_HEADER_METHOD,
    HTTP2_HEADER_PATH
} = http2.constants;

const mountOperationSchema = Joi.object().keys({
    [HTTP2_HEADER_METHOD]: Joi.string().required(),
    [HTTP2_HEADER_PATH]: Joi.string().required(),
    'request-id': Joi.string().required(),
    'source-ip': Joi.string().required(),
    'nfs-export': Joi.string().required(),
    version: Joi.string()
});

const umountOperationSchema = Joi.object().keys({
    [HTTP2_HEADER_METHOD]: Joi.string().required(),
    [HTTP2_HEADER_PATH]: Joi.string().required()
});

const getFileOperationSchema = Joi.object().keys({
    [HTTP2_HEADER_METHOD]: Joi.string().required(),
    [HTTP2_HEADER_PATH]: Joi.string().required(),
    'request-id': Joi.string().required(),
    path: Joi.string().required()
});

const deleteFileOperationSchema = Joi.object().keys({
    [HTTP2_HEADER_METHOD]: Joi.string().required(),
    [HTTP2_HEADER_PATH]: Joi.string().required(),
    'request-id': Joi.string().required(),
    path: Joi.string().required()
});

const getSymlinkOperationSchema = Joi.object().keys({
    [HTTP2_HEADER_METHOD]: Joi.string().required(),
    [HTTP2_HEADER_PATH]: Joi.string().required(),
    'request-id': Joi.string().required(),
    path: Joi.string().required()
});

const listWithStatsOperationSchema = Joi.object().keys({
    [HTTP2_HEADER_METHOD]: Joi.string().required(),
    [HTTP2_HEADER_PATH]: Joi.string().required(),
    'request-id': Joi.string().required(),
    path: Joi.string()
});

const uploadFileOperationSchema = Joi.object().keys({
    [HTTP2_HEADER_METHOD]: Joi.string().required(),
    [HTTP2_HEADER_PATH]: Joi.string().required(),
    'request-id': Joi.string().required(),
    entry: Joi.string().required()
});

const secureMkdirsOperationSchema = Joi.object().keys({
    [HTTP2_HEADER_METHOD]: Joi.string().required(),
    [HTTP2_HEADER_PATH]: Joi.string().required(),
    'request-id': Joi.string().required()
});

module.exports = {
    'umount-endpoint': umountOperationSchema,
    'mount-endpoint': mountOperationSchema,
    'list-with-stats': listWithStatsOperationSchema,
    'get-file': getFileOperationSchema,
    'get-symlink': getSymlinkOperationSchema,
    'delete-file': deleteFileOperationSchema,
    'upload-file': uploadFileOperationSchema,
    'upload-dir': uploadFileOperationSchema,
    'upload-symlink': uploadFileOperationSchema,
    'secure-mkdirs': secureMkdirsOperationSchema
};
