const express = require('express');
const cifsAcl = require('cifs-acl');
const { unescape } = require('querystring');
const aclserverIncomingIPCMessagesSchemes = require('../messages/acl-server/ipc-incoming-messages');
const validateMessage = require('../messages/schemas/message-validator');
const getLogger = require('../lib/logger/logger');

const logger = getLogger();

const app = express();

process.on('uncaughtException', err => logger.error('Uncaught exception', err));
process.on('unhandledRejection', (err, promise) => logger.error('Unhandled promise rejection', promise, err));

app.use(express.json());
app.use(express.urlencoded({ extended: false }));

app.get('/smb/get-acl/:path(*)', (req, res) => {
    try {
        res.status(200).json(cifsAcl.get(unescape(req.params.path)));
    } catch (err) {
        res.status(403).json({ code: 403, message: err.toString().trim() });
    }
});

app.put('/smb/set-acl', (req, res) => {
    try {
        const { body: { path, acl } } = req;
        cifsAcl.set(path, acl);
        res.status(200).json();
    } catch (err) {
        res.status(403).json({ code: 403, message: err.toString().trim() });
    }
});

function startServer(port) {
    try {
        app.listen(port);
    } catch (err) {
        logger.error('Failed staring ACL server with error:', err);
        process.exit(0);
    }
}

process.on('message', message => {
    logger.info('Got IPC message', message);
    if (validateMessage(message, 'IPC', aclserverIncomingIPCMessagesSchemes[message.type])) {
        switch (message.type) {
            case 'create-acl-server':
                startServer(message.port);
                break;
            default:
                break;
        }
    }
});
