const { cloneDeep } = require('lodash');
const sqsMasterIncomingMessagesSchemes = require('../../../src/messages/master/incoming-messages');

describe('masterCopySchema validations ', () => {
    const masterCopySchema = sqsMasterIncomingMessagesSchemes.copy;
    const validMasterCopy = {
        relationshipId: '1',
        source: {
            cifs: {
                host: '1.1.1.1',
                share: 'share',
                username: 'username',
                password: 'password'
            }
        },
        target: {
            s3: {
                bucket: 'bucket',
                region: 'us-east-1',
                encryption: {
                    kms: {
                        keyId: '11111'
                    }
                }
            }
        },
        scannerQueue: 'https://sqs.us-east-1.amazonaws.com/718273455463/scanner',
        transferrerQueue: 'https://sqs.us-east-1.amazonaws.com/718273455463/transferrer',
        settings: {
            gracePeriod: 0,
            deleteOnSource: false,
            deleteOnTarget: true,
            objectTagging: true,
            retries: 3,
            copyAcl: false,
            fileTypes: {
                files: true,
                directories: true,
                symlinks: true
            },
            files: {
                excludeExtensions: [],
                minSize: 0,
                maxSize: Number.MAX_SAFE_INTEGER,
                minDate: '1970-01-01',
                maxDate: null
            }
        }
    };

    test('masterCopySchema valid command', () => expect(masterCopySchema.validate(validMasterCopy).error).toBeUndefined());

    test('masterCopySchema gracePeriod not valid', () => {
        const invalidMasterCopy = cloneDeep(validMasterCopy);
        invalidMasterCopy.gracePeriod = 1.1;
        expect(masterCopySchema.validate(invalidMasterCopy).error.details[0])
            .toEqual(expect.objectContaining({ message: '"gracePeriod" is not allowed' }));
    });

    test('masterCopySchema source endpoint contains more than one protocol', () => {
        const invalidMasterCopy = cloneDeep(validMasterCopy);
        invalidMasterCopy.source.nfs = {
            host: '2.2.2.2',
            version: 4.1,
            export: 'export'
        };
        expect(masterCopySchema.validate(invalidMasterCopy).error.details[0])
            .toEqual(expect.objectContaining({ message: '"source" contains a conflict between exclusive peers [cifs, nfs, efs, s3, local, azure, gcp, snfs]' }));
    });

    test('masterCopySchema grace period is negative', () => {
        const invalidMasterCopy = cloneDeep(validMasterCopy);
        invalidMasterCopy.settings.gracePeriod = -1;
        expect(masterCopySchema.validate(invalidMasterCopy).error.details[0])
            .toEqual(expect.objectContaining({ message: '"settings.gracePeriod" must be larger than or equal to 0' }));
    });
});
