const { cloneDeep } = require('lodash');
const { SCAN_MODE_SOURCE_ONLY } = require('../../../src/lib/consts');
const scannerIncomingSQSSchema = require('../../../src/messages/scanner/sqs-incoming-messages');

describe('scannerIncomingSQSSchema validations ', () => {
    const validscannerScan = {
        relationshipId: '1',
        source: {
            cifs: {
                host: '1.1.1.1',
                share: 'share',
                username: 'username',
                password: 'password'
            }
        },
        target: {
            s3: {
                bucket: 'bucket',
                region: 'us-east-1',
                encryption: {
                    kms: {
                        keyId: '11111'
                    }
                }
            }
        },
        type: SCAN_MODE_SOURCE_ONLY
    };

    test('scannerIncomingSQSSchema valid command', () => expect(scannerIncomingSQSSchema.validate(validscannerScan).error).toBeUndefined());

    test('scannerIncomingSQSSchema type not valid', () => {
        const invalidCreateRelationship = cloneDeep(validscannerScan);
        invalidCreateRelationship.type = 'Type';
        expect(scannerIncomingSQSSchema.validate(invalidCreateRelationship).error.details[0])
            .toEqual(expect.objectContaining({ message: '"type" must be one of [SCAN_MODE_SOURCE_ONLY, SCAN_MODE_TARGET_ONLY, SCAN_MODE_SOURCE_AND_TARGET]' }));
    });

    test('scannerIncomingSQSSchema no type ', () => {
        const invalidCreateRelationship = cloneDeep(validscannerScan);
        delete invalidCreateRelationship.type;
        expect(scannerIncomingSQSSchema.validate(invalidCreateRelationship).error.details[0])
            .toEqual(expect.objectContaining({ message: '"type" is required' }));
    });

    test('scannerIncomingSQSSchema source endpoint contains more than one protocol', () => {
        const invalidCreateRelationship = cloneDeep(validscannerScan);
        invalidCreateRelationship.source.nfs = {
            host: '2.2.2.2',
            version: 4.1,
            export: 'export'
        };
        expect(scannerIncomingSQSSchema.validate(invalidCreateRelationship).error.details[0])
            .toEqual(expect.objectContaining({ message: '"source" contains a conflict between exclusive peers [cifs, nfs, efs, s3, local, azure, gcp, snfs]' }));
    });
});
