const { cloneDeep } = require('lodash');
const {
    TYPE_FILE, ACTION_DELETE_TARGET, ACTION_COPY
} = require('../../../src/lib/consts');
const sqsTransferrerIncomingMessagesSchemes = require('../../../src/messages/transferrer/sqs-incoming-messages');

describe('transferrerIncomingSQSSchema validations ', () => {
    // const validEndPoingS3 = {
    //     s3: {
    //         bucket: 'bucket',
    //         path: '',
    //         encryption: {
    //             protocol: 'kms',
    //             keyId: '11111'
    //         }
    //     }
    // };

    const validDelete = {
        relationshipId: '1',
        target: {
            s3: {
                bucket: 'bucket',
                region: 'us-east-1',
                encryption: {
                    kms: {
                        keyId: '11111'
                    }
                }
            }
        },
        type: ACTION_DELETE_TARGET

    };

    const validCopy = {
        relationshipId: '1',
        source: {
            cifs: {
                host: '1.1.1.1',
                share: 'share',
                username: 'username',
                password: 'password'
            }
        },
        target: {
            s3: {
                bucket: 'bucket',
                region: 'us-east-1',
                encryption: {
                    kms: {
                        keyId: '11111'
                    }
                }
            }
        },
        type: ACTION_COPY,
        entry: {
            path: 'file.txt',
            type: TYPE_FILE,
            size: 50
        }
    };

    test('transferrerIncomingSQSSchema valid delete command', () => expect(sqsTransferrerIncomingMessagesSchemes[ACTION_DELETE_TARGET].validate(validDelete).error).toBeUndefined());

    test('transferrerIncomingSQSSchema valid copy command', () => expect(sqsTransferrerIncomingMessagesSchemes[ACTION_COPY].validate(validCopy).error).toBeUndefined());

    test('transferrerIncomingSQSSchema type not valid', () => {
        const invalidDelete = cloneDeep(validDelete);
        invalidDelete.type = 'Type';
        expect(sqsTransferrerIncomingMessagesSchemes[ACTION_DELETE_TARGET].validate(invalidDelete).error.details[0])
            .toEqual(expect.objectContaining({ message: '"type" must be one of [COPY, DELETE_SOURCE, DELETE_TARGET]' }));
    });

    test('transferrerIncomingSQSSchema no type ', () => {
        const invalidDelete = cloneDeep(validDelete);
        delete invalidDelete.type;
        expect(sqsTransferrerIncomingMessagesSchemes[ACTION_DELETE_TARGET].validate(invalidDelete).error.details[0])
            .toEqual(expect.objectContaining({ message: '"type" is required' }));
    });

    test('transferrerIncomingSQSSchema copy without entry', () => {
        const invalidCopy = cloneDeep(validCopy);
        delete invalidCopy.entry;
        expect(sqsTransferrerIncomingMessagesSchemes[ACTION_COPY].validate(invalidCopy).error.details[0])
            .toEqual(expect.objectContaining({ message: '"entry" is required' }));
    });

    test('transferrerIncomingSQSSchema copy without source', () => {
        const invalidCopy = cloneDeep(validCopy);
        delete invalidCopy.source;
        expect(sqsTransferrerIncomingMessagesSchemes[ACTION_COPY].validate(invalidCopy).error.details[0])
            .toEqual(expect.objectContaining({ message: '"source" is required' }));
    });
});
