const Promise = require('bluebird');

/**
 * Make any changes you need to make to the database here
 * and return promise
 * 'this' is the mongoose object
 */
function up() {
    const { db } = this.connection;
    return Promise.resolve()
        .then(() => {
            const usersDb = db.collection('users');
            const apiKeysDb = db.collection('apikeys');

            return usersDb.find().toArray()
                .then(users => Promise.map(users, user => {
                    usersDb.update({ _id: user._id }, { $unset: { lastApiUsage: '' } });
                }))
                .then(() => apiKeysDb.drop())
                .catch(() => undefined);
        });
}

/**
 * Make any changes that UNDO the up function side effects here (if possible)
 * and return promise
 * 'this' is the mongoose object
 */
function down() {
    return this.model('User').countDocuments();
}

module.exports = { up, down };
