
/**
 * Make any changes you need to make to the database here
 * and return promise
 * 'this' is the mongoose object
 */


async function up() {
    const { db } = this.connection;
    const relationshipsDb = db.collection('relationships');
    //in case we have s3 endpoint but without provider it is s3 provider
    await relationshipsDb.updateMany({'source.protocol' : 's3', 'source.s3.provider': {$exists: false}},
        {$set :{'source.s3.provider':'s3'}});

    await relationshipsDb.updateMany({'target.protocol' : 's3', 'target.s3.provider': {$exists: false}},
        {$set :{'target.s3.provider':'s3'}});


    await relationshipsDb.updateMany({'source.protocol' : 'sgws', 'source.sgws.provider': {$exists: false}},
        {$set :{'source.sgws.provider':'sgws'}});


    await relationshipsDb.updateMany({'target.protocol' : 'sgws', 'target.sgws.provider': {$exists: false}},
        {$set :{'target.sgws.provider':'sgws'}});


    // update source in relationship

    await relationshipsDb.updateMany({ 'source.protocol': 'sgws' }, { $rename: { 'source.sgws': 'source.s3' } });
    await relationshipsDb.updateMany({ 'source.protocol': 'sgws' }, { $set: { 'source.protocol': 's3' } });
    await relationshipsDb.updateMany({  'target.protocol': 'sgws' }, { $rename: {  'target.sgws': 'target.s3'} });
    await relationshipsDb.updateMany({ 'target.protocol': 'sgws' }, { $set: { 'target.protocol': 's3' } });

    const timelineDb = db.collection('timelinev2');
    // update source in timelineV2

    await timelineDb.updateMany({'relationship.source.protocol' : 's3', 'relationship.source.s3.provider': {$exists: false}},
        {$set :{'relationship.source.s3.provider':'s3'}});

    await timelineDb.updateMany({'relationship.target.protocol' : 's3', 'relationship.target.s3.provider': {$exists: false}},
        {$set :{'relatinoship.target.s3.provider':'s3'}});


    await timelineDb.updateMany({'relationship.source.protocol' : 'sgws', 'relationship.source.sgws.provider': {$exists: false}},
        {$set :{'relationship.source.sgws.provider':'sgws'}});


    await timelineDb.updateMany({'relationship.target.protocol' : 'sgws', 'relationship.target.sgws.provider': {$exists: false}},
        {$set :{'relationship.target.sgws.provider':'sgws'}});


    await timelineDb.updateMany({ 'relationship.source.protocol': 'sgws' }, { $rename: { 'relationship.source.sgws': 'relationship.source.s3' } });
    await timelineDb.updateMany({ 'relationship.target.protocol': 'sgws' }, { $rename: { 'relationship.target.sgws': 'relationship.target.s3' } });
    await timelineDb.updateMany({ 'relationship.source.protocol': 'sgws' }, { $set: { 'relationship.source.protocol': 's3' } });
    await timelineDb.updateMany({ 'relationship.target.protocol': 'sgws' }, { $set: { 'relationship.target.protocol': 's3' } });
}

/**
 * Make any changes that UNDO the up function side effects here (if possible)
 * and return promise
 * 'this' is the mongoose object
 */
async function down() {
    return this.model('User').countDocuments();
}

module.exports = { up, down };

