
/**
 * Make any changes you need to make to the database here
 * and return promise
 * 'this' is the mongoose object
 */
async function up() {
    const { db } = this.connection;
    const relationshipDb = db.collection('relationships');
    const allRelationships = await relationshipDb.find({}).toArray();
    await Promise.all(allRelationships.map(relationship => {
        const {_id, sync : {inDays, inHours, inMinutes, autoSync, nextTime}} = relationship;
        const schedule = {syncInDays:inDays, syncInHours:inHours, syncInMinutes:inMinutes, syncWhenCreated:true, nextTime, isEnabled: (autoSync === 'ON') || (inHours > 0 &&
                inMinutes > 0 && inDays > 0)};
        return relationshipDb.update({_id}, {$set:{'settings.schedule':schedule}});
    }));
    await relationshipDb.update({}, {$unset:{sync:''}}, {multi:true});
}

/**
 * Make any changes that UNDO the up function side effects here (if possible)
 * and return promise
 * 'this' is the mongoose object
 */
async function down() {
    return this.model('User').countDocuments();
}

module.exports = { up, down };

