#!/bin/bash

# input:
# * environment
# * account id
#
# This script setup an account so temporary credentials can be geenrated by CloudSync.
# It requires jq in the path - https://stedolan.github.io/jq/
# The script does the following:
# 1. create policy that
# ** allows "sqs:SendMessage", "sqs:SendMessageBatch" on queues with pattern  STATUSES_${environment}_
# ** allow "sqs:DeleteMessage", "sqs:DeleteMessageBatch", "sqs:ReceiveMessage" on queues with name pattern COMMANDS_${environment}_
#
# 2. create a role with:
# ** name pattern that include the environment
# ** policy statement that define a trust relationship to user 'root' in the selected account
#
# 3. attach the policy created in step 1 to the role created in step 2

cloud_sync_environment=$1
aws_account_id=$2
assume_role_name=cloud_sync_assume_role_${cloud_sync_environment}
assume_role_policy_arn=''

TRUST_POLICY=$(cat << EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Effect": "Allow",
      "Principal": {
        "AWS": "arn:aws:iam::${aws_account_id}:root"
      },
      "Action": "sts:AssumeRole",
      "Condition": {}
    }
  ]
}
EOF
)

CLOUD_SYNC_ASSUME_ROLE_POLICY=$(cat << EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Effect": "Allow",
      "Action": [
        "sqs:SendMessage",
        "sqs:SendMessageBatch"
      ],
      "Resource": "arn:aws:sqs:*:${aws_account_id}:STATUSES_${cloud_sync_environment}_*"
    },
    {
      "Effect": "Allow",
      "Action": [
        "sqs:DeleteMessage",
        "sqs:DeleteMessageBatch",
        "sqs:ReceiveMessage"
      ],
      "Resource": "arn:aws:sqs:*:${aws_account_id}:COMMAND_${cloud_sync_environment}_*"
    }
  ]
}
EOF
)

create_role_policy() {
	temp=`aws iam create-policy --policy-name  cloud_sync_assume_role_policy_${cloud_sync_environment} --policy-document "${CLOUD_SYNC_ASSUME_ROLE_POLICY}" | jq .Policy.Arn`
	temp="${temp%\"}"
	assume_role_policy_arn="${temp#\"}"
}

create_trust_role() {
    aws iam create-role --role-name $assume_role_name --assume-role-policy-document "${TRUST_POLICY}"
}

attach_role_policy() {
    aws iam attach-role-policy --role-name $assume_role_name --policy-arn ${assume_role_policy_arn}
}

create_role_policy
echo "policy created with arn - $assume_role_policy_arn"

create_trust_role

#attach_role_policy

# clean-up for testing - DELETE ME
aws iam aws iam list-role-policies --role-name $assume_role_name

aws iam detach-role-policy --role-name $assume_role_name --policy-arn ${assume_role_policy_arn}
#aws iam delete-role --role-name $assume_role_name
#aws iam delete-policy --policy-arn ${assume_role_policy_arn}