const { SERVICE_REGION, SERVER_HOST } = require('../../utils/consts');
const [environment] = SERVER_HOST.split('.');
const getLogger = require('../../utils/logger');
const logger = getLogger();

let ecs;


function getEcs() {
    if (!ecs) {
        ecs = new AWS.ECS({ region: SERVICE_REGION });
    }
    return ecs;
}


async function listClusters() {
    const ecs = getEcs();
    const result = await ecs.listClusters({}).promise();  // without token we only have 4 clusters : e2e, dev, prod, update

    return result.clusterArns;
}


async function getContainerInstances(cluster, status = 'ACTIVE') {
    const ecs = getEcs();
    return ecs.listContainerInstances({cluster, status }).promise();
}

async function describeContainerInstances(cluster, containerInstances) {
    const result = await ecs.describeContainerInstances({cluster, containerInstances}).promise();
    return result.containerInstances;
}

async function findRunningInstanceIds() {
    logger.info('Find number of running instances');
    const clusters = await listClusters();
    const cluster = clusters.find(cluster => cluster.includes(environment));
    logger.info('Current cluster found', cluster);
    const containersOfCluster = await getContainerInstances(cluster);
    logger.info('list of clusters containers', containersOfCluster);
    const containersDetails = await describeContainerInstances(cluster, containersOfCluster.containerInstanceArns);
    logger.info('containersDetails', JSON.stringify(containersDetails, null, 4));
    return containersDetails.map(container => container.ec2InstanceId).sort();
}

module.exports = { listClusters, findRunningInstanceIds, getContainerInstances, describeContainerInstances};