const axios = require('axios');
const {validateResponse} = require('../utils/schema-validation');
const {TENANCY_SERVER_ADDRESS, TENANCY_PATH, TENANCY_ACCOUNT_PATH} = require('../utils/consts');
const {getUserToken} = require('../utils/async-local-storage');
const {
    tenancyGetAccountsResponseSchema, tenancyCreateAccountsResponseSchema
} = require('../schemas/tenancy-schemas');

const getLogger = require('../utils/logger');
const logger = getLogger();


async function getAccounts() {
    logger.info('Get tenancy accounts', TENANCY_SERVER_ADDRESS);

    const {data} = await axios.get(`${TENANCY_SERVER_ADDRESS}${TENANCY_PATH}${TENANCY_ACCOUNT_PATH}`, {
        headers: {
            authorization: getUserToken()
        }
    });

    validateResponse(data, tenancyGetAccountsResponseSchema);

    return data;
}

async function createAccount(accountName) {
    logger.info(`Create new tenancy account: ${accountName}`);

    const {data} = await axios.post(`${TENANCY_SERVER_ADDRESS}${TENANCY_PATH}${TENANCY_ACCOUNT_PATH}/${accountName}`, {}, {
        headers: {
            authorization: getUserToken()
        }
    });

    validateResponse(data, tenancyCreateAccountsResponseSchema);
    logger.info('create account response', data);
    return data;
}

module.exports = {
    getAccounts, createAccount
};