const moment = require('moment');
const {
    TIER_1_BILLING_PER_HOUR, TIER_2_BILLING_PER_HOUR,
    TIER_3_BILLING_PER_HOUR
} = require('../utils/consts');
const {BadRequest} = require('../utils/errors');


function calculateSumOfBillingInATier(numOfRelationships, numOfHours, tier) {
    let billingPerHour;

    if (tier === 1) {
        billingPerHour = TIER_1_BILLING_PER_HOUR;
    } else if (tier === 2) {
        billingPerHour = TIER_2_BILLING_PER_HOUR;
    } else {
        billingPerHour = TIER_3_BILLING_PER_HOUR;
    }

    return Number((numOfHours * numOfRelationships * billingPerHour).toFixed(3));
}

function validateMonthAndYear(month, year) {
    const monthsArr = moment.months();

    if (!monthsArr.find(monthInTheArr => monthInTheArr === month)) {
        throw new BadRequest('Month should be a full month name');
    }

    if (year.length !== 4) {
        throw new BadRequest('Year should contain 4 digits');
    }

    if (year > moment().year()) {
        throw new BadRequest('Year should be current or previous year');
    }
}


module.exports = {
    calculateSumOfBillingInATier, validateMonthAndYear
};