const hyperid = require('hyperid');
const { MP_PRODUCT_CODE_METERING, MP_PRODUCT_CODE_CONTRACT } = require('../utils/consts');

function buildProcessedMeteringRecordResponse(customerIdentifier, dimension, quantity, timestamp, status) {
    return {
        MeteringRecordId: hyperid().uuid,
        Status: status,
        UsageRecord: {
            CustomerIdentifier: customerIdentifier,
            Dimension: dimension,
            Quantity: quantity,
            Timestamp: timestamp
        }
    };
}

function buildUnprocessedMeteringRecordResponse(customerIdentifier, dimension, quantity, timestamp) {
    return {
        CustomerIdentifier: customerIdentifier,
        Dimension: dimension,
        Quantity: quantity,
        Timestamp: timestamp
    };
}

AWS.mock('MarketplaceMetering', 'resolveCustomer', params => ({
    promise: () => {
        if (params.RegistrationToken === 'WRONG_TOKEN') {
            throw new Error({
                message: 'Registration token is invalid',
                code: 'InvalidTokenException'
            });
        } else if (params.RegistrationToken === 'CONTRACT_TOKEN') {
            return {
                CustomerIdentifier: 'PASTRAMA-MIA',
                ProductCode: MP_PRODUCT_CODE_CONTRACT
            };
        } else {
            return {
                CustomerIdentifier: 'PASTRAMA-MIA',
                ProductCode: MP_PRODUCT_CODE_METERING
            };
        }
    }
}));

AWS.mock('MarketplaceMetering', 'batchMeterUsage', params => ({
    promise: () => {
        const timestamp = new Date().toISOString();
        const customerIdObj = {};
        // building results from the requested records themselves and adding some mixed data
        const usageRecords = params.UsageRecords;
        let recordsToProcess;
        let unprocessedRecords;

        if (usageRecords.length > 1) {
            recordsToProcess = usageRecords.slice(0, usageRecords.length - 1);
            unprocessedRecords = [
                buildUnprocessedMeteringRecordResponse(usageRecords[usageRecords.length - 1].CustomerIdentifier,
                    usageRecords[usageRecords.length - 1].Dimension, usageRecords[usageRecords.length - 1].Quantity,
                    timestamp)];
        } else {
            recordsToProcess = usageRecords;
            unprocessedRecords = [];
        }

        const results = recordsToProcess.map(record => {
            if (customerIdObj[record.CustomerIdentifier]) {
                if (customerIdObj[record.CustomerIdentifier][record.Dimension]) {
                    return buildProcessedMeteringRecordResponse(record.CustomerIdentifier, record.Dimension, record.Quantity, timestamp, 'DuplicateRecord');
                }
                customerIdObj[record.CustomerIdentifier][record.Dimension] = true;
                return buildProcessedMeteringRecordResponse(record.CustomerIdentifier, record.Dimension, record.Quantity, timestamp, 'Success');
            }
            customerIdObj[record.CustomerIdentifier] = { [record.Dimension]: true };
            return buildProcessedMeteringRecordResponse(record.CustomerIdentifier, record.Dimension, record.Quantity, timestamp, 'Success');
        });

        results.push(buildProcessedMeteringRecordResponse(params.UsageRecords[0].CustomerIdentifier, params.UsageRecords[0].Dimension, params.UsageRecords[0].Quantity, timestamp, 'DuplicateRecord'));
        results.push(buildProcessedMeteringRecordResponse('CustomerNotSubscribed', params.UsageRecords[0].Dimension, params.UsageRecords[0].Quantity, timestamp, 'CustomerNotSubscribed'));

        unprocessedRecords.push(buildUnprocessedMeteringRecordResponse('nonExistingCustomerIdentifier', 'Tier1', 5, timestamp));

        return {
            Results: results,
            UnprocessedRecords: unprocessedRecords
        };
    }
}));
