class ExtendedError extends Error {
    constructor(message, statusCode, errorCode) {
        super(message);
        this.statusCode = statusCode;
        this.errorCode = errorCode || statusCode;
        Error.captureStackTrace(this, this.constructor);
    }
}

class BadRequest extends ExtendedError {
    constructor(message, errorCode) {
        super(message || 'Bad request', 400, errorCode);
    }
}

class Unauthorized extends ExtendedError {
    constructor(message, errorCode) {
        super(message || 'Unauthorized', 401, errorCode);
    }
}

class Forbidden extends ExtendedError {
    constructor(message, errorCode) {
        super(message || 'Forbidden', 403, errorCode);
    }
}

class NotFound extends ExtendedError {
    constructor(message, errorCode) {
        super(message || 'The requested resource couldn\'t be found', 404, errorCode);
    }
}

class PreconditionFailed extends ExtendedError {
    constructor(message, errorCode) {
        super(message || 'Precondition Failed', 412, errorCode);
    }
}

module.exports = {
    PreconditionFailed, NotFound, BadRequest, ExtendedError, Forbidden, Unauthorized
};
