const moment = require('moment');
const {Account} = require('../../src/models/account');
const {addTrialDaysForInternalUsers, calculateDaysLeftForTrial} = require('../../src/operations/account-operations');
const {should} = require('../globals');

const name = 'name';
const trialExpiry = moment().subtract(1, 'years');
const support = {
    serialNumber: '12345',
    status: 'unregistered'
};
const tenancyAccountId = 'a';

describe('account-operations', () => {

    beforeEach(() => Account.deleteMany());

    it('addTrialDaysForInternalUsers- automaticExtension is true', async() => {
        const account = await Account.create({
            name, trialExpiry, support, tenancyAccountId, automaticExtension: true
        });
        should.exist(account);
        const newTrial = await addTrialDaysForInternalUsers(account);
        const monthFromNow = moment().startOf('day').add(14, 'day');
        const expectedDay = monthFromNow.weekday();
        const expectedMonth = monthFromNow.month();
        const actualDay = newTrial.getDay();
        const actualMonth = newTrial.getMonth();
        actualDay.should.equal(expectedDay);
        actualMonth.should.equal(expectedMonth);
    });

    it('addTrialDaysForInternalUsers- automaticExtension is false', async() => {
        const account = await Account.create({
            name, trialExpiry, support, tenancyAccountId, automaticExtension: false
        });

        should.exist(account);
        const newTrial = await addTrialDaysForInternalUsers(account);
        const expectedDay = newTrial.getDay();
        const expectedMonth = newTrial.getMonth();
        const actualDay = newTrial.getDay();
        const actualMonth = newTrial.getMonth();
        actualDay.should.equal(expectedDay);
        actualMonth.should.equal(expectedMonth);
    });

    it('calculateDaysLeftForTrial- expired trial', async() => {
        calculateDaysLeftForTrial(trialExpiry).should.equal(-1);
    });

    it('calculateDaysLeftForTrial- valid trial', async() => {
        const trialExpiry = moment().add(3, 'days');
        calculateDaysLeftForTrial(trialExpiry).should.equal(3);
    });

    it('calculateDaysLeftForTrial- 0 days left for the trial', async() => {
        const trialExpiry = moment();
        calculateDaysLeftForTrial(trialExpiry).should.equal(0);
    });

});

