const fs = require('fs');
const  updateSubscription = require('../../src/operations/subscription-operations');
const {Account} = require('../../src/models/account');
const Relationship = require('../../src/models/relationship');
const DataBroker = require('../../src/models/data-broker');


describe('updateSubscription', () => {
    const path = require('path');

    beforeEach(async() => {
        await Promise.all([Account.deleteMany(), Relationship.deleteMany(), DataBroker.deleteMany()]);
        const accounts = JSON.parse(fs.readFileSync(path.resolve('./test/resources', 'accounts.json'), 'utf8'));
        return Account.insertMany(accounts);
    });

    after(() => Account.deleteMany());

    async function validateAccountsUpdated(subscription, accounts, expectedSubscription) {
        try {
            await updateSubscription(subscription, accounts);
            const accountsIds = accounts.map(account => ({ _id: account._id }));
            const accountdFromDb = await Account.find({ $or: accountsIds }).exec();
            accountdFromDb.forEach(account => {
                if (!(account.subscription.type === expectedSubscription.type && account.subscription.status === expectedSubscription.status)) {
                    throw new Error(`subscription ${account.subscription} is not as expected ${JSON.stringify(expectedSubscription)}`);
                }
            });
        } catch (err) {
            throw new Error(err);
        }
    }

    it('update subscription with empty subscription- everything should be the same', async() => {
        const accounts = await Account.find({ 'subscription.status': 'unsubscribed-init' }).exec();
        validateAccountsUpdated(undefined, accounts, {
            updatedAt: '1487146566938',
            status: 'unsubscribed-init',
            type: 'PAYGO'
        });
    });

    it('update subscription with PAYGO subscription', async() => {
        const accounts = await Account.find({ 'subscription.status': 'unsubscribed-init' }).exec();
        validateAccountsUpdated({
            updatedAt: Date.now(),
            status: 'subscribe-success',
            type: 'PAYGO',
            customerIdentifier: 'AD'
        }, accounts, {
            updatedAt: Date.now(),
            status: 'subscribe-success',
            type: 'PAYGO',
            customerIdentifier: 'AD'
        });
    });

    it('update subscription with CONTRACT subscription', async() => {
        const accounts = await Account.find({ 'subscription.type': 'PAYGO' }).exec();
        validateAccountsUpdated({
            updatedAt: Date.now(),
            status: 'subscribe-success',
            type: 'CONTRACT',
            customerIdentifier: 'AD'
        }, accounts, {
            updatedAt: Date.now(),
            status: 'subscribe-success',
            type: 'CONTRACT',
            customerIdentifier: 'AD'
        });
    });

    it('update CONTRACT subscription with PAYGO subscription should not be updated', async() => {
        const accounts = await Account.find({ 'subscription.type': 'CONTRACT' }).exec();
        validateAccountsUpdated({
            updatedAt: Date.now(),
            status: 'subscribe-success',
            type: 'PAYGO',
            customerIdentifier: 'AD'
        }, accounts, {
            updatedAt: Date.now(),
            status: 'subscribe-success',
            type: 'CONTRACT',
            customerIdentifier: 'AD'
        });
    });
});
