import React, {useState} from 'react';
import Select from 'react-select';
import _ from "lodash";
import DialogLayout from '../dialog/DialogLayout';
require ("./accountSelectionDialog.scss");

const AccountSelectionDialog = ({closeDialog, accounts, setActiveAccount, uid}) => {
    const [selectedAccount, setSelectedAccount] = useState(accounts[0]);
    const accountOptions = _.map(accounts, account => {return {label: account.name, value: account.accountId}});

    const handleAccountChange = (e) => {
        const accountId = e.value;
        const account = _.find(accounts, account => account.accountId === accountId);
        setSelectedAccount(account);
    };

    const setAccount = () => {
        setActiveAccount({accountId: selectedAccount.accountId, uid});
        closeDialog();
    };

    return (<DialogLayout
            title="Account Selection"
            onConfirm={setAccount}
            confirmButtonText="Select Account"
        >
        <div className="select-account">
            <p>Select a Cloud Central account to manage the sync relationships for. You can switch between accounts at any time from the User Settings menu.</p>
            <label>Select an account:</label>
            <Select className="Select account-options"
                    classNamePrefix="Select"
                    options={accountOptions}
                    isSearchable={false}
                    isClearable={false}
                    onChange={handleAccountChange}
                    value={_.find(accountOptions, (option) => option.value === selectedAccount.accountId)}
                    isLoading={!accounts}/>
        </div>
    </DialogLayout>)
};

export default AccountSelectionDialog;