import React from 'react';
import {connect} from 'react-redux';
import {updateCmIntegration, setCmIntegrationDetails} from '../../store/global/action_creators';
import {routesContainer} from '../../store/global/action_creators_consts';
import _ from "lodash";
import {setActiveAccount} from "../../utils/messages-utils";
import useRunOnce from '../../hooks/useRunOnce';
import { parse } from 'query-string';
import MainLoader from '../_common_/MainLoader/MainLoader';

const supportedWorkingEnvironmentTypes = ["ANF", "CVS", "CVO", "ONPREM", "S3"];

const CmIntegrationEntryPoint = (props) => {
    const {auth, updateCmIntegration, setActiveAccount, setCmIntegrationDetails} = props;
    const {data: {uid}} = auth;
    const queryParams = parse(window.location.search);
    const accountId = _.get(queryParams, 'accountId', null);
    const workingEnvironmentName = _.get(queryParams, 'workingEnvironmentName', null);
    const workingEnvironmentTypeParam = _.get(queryParams, 'workingEnvironmentType', null);
    const workingEnvironmentType = _.includes(supportedWorkingEnvironmentTypes, workingEnvironmentTypeParam)
        ? workingEnvironmentTypeParam
        : null;
    const isSourceParam = _.get(queryParams, 'isSource', null);
    const isSource = isSourceParam === "true" ? true : isSourceParam === "false" ? false : null;
    const viewDashboard = !_.isBoolean(isSource);

    useRunOnce(() => {
        updateCmIntegration();
        setActiveAccount({accountId, uid}); //this also sets the account header
        setCmIntegrationDetails({workingEnvironmentName, workingEnvironmentType, isSource, viewDashboard});
        if (viewDashboard) {
            routesContainer.routes.push("/dashboard");
        }
        else {
            routesContainer.routes.push("/drag-source-and-target");
        }
    });

    return <MainLoader/>;
};

const mapStateToProps = (state) => {
    return {
        auth: state.global.auth,
        _ui:  {...state.syncReducer._ui, ...state.global._ui}
    }
};

export default connect(mapStateToProps, {
    updateCmIntegration,
    setCmIntegrationDetails,
    setActiveAccount
})(CmIntegrationEntryPoint);
