import React, {useState, useCallback} from "react";
import {
    DEPLOY_PROGRESS_NOTIFICATION,
    FM_AGENT_TYPE_AWS,
    FM_AGENT_TYPE_AZURE,
    FM_AGENT_TYPE_GCP,
    FM_AGENT_TYPE_ONPREM,
    NOTIFICATION_TYPES
} from '../../consts';
import InstanceDetailsAws from './InstanceDetailsAws';
import InstanceDetailsGcp from './InstanceDetailsGcp';
import InstanceDetailsAzure from './InstanceDetailsAzure';
import InstanceDetailsOnprem from './InstanceDetailsOnprem';
import {NotificationError} from '../notifications/NotificationItems';
import {connect} from "react-redux";
import {addNotification} from "../../store/global/action_creators";
import {getRelationships} from "../../store/wizard/action_creators";
import {addDeployment} from '../../store/deploy/action_creators';
import "./instanceDetails.scss";

const InstanceDetails = props => {
    const {type, closePanel, isAccelerate, addNotification, getRelationships} = props;
    const [stepError, setStepError] = useState(null);

    const onFinish = useCallback(() => {

        closePanel();

        if (isAccelerate) {
            //Need to happen only in dashboard, not needed in the wizard
            getRelationships();
            if (type !== FM_AGENT_TYPE_ONPREM.name) {
                addNotification({
                    type: NOTIFICATION_TYPES.INFO,
                    text: DEPLOY_PROGRESS_NOTIFICATION,
                    shortDescription: "Data broker creation is in progress."
                });
            }
        }
    }, [closePanel, isAccelerate, addNotification, type, getRelationships]);

    return (<>
        {type === FM_AGENT_TYPE_AWS.name && <InstanceDetailsAws setStepError={setStepError} onFinish={onFinish} {...props}/>}
        {type === FM_AGENT_TYPE_AZURE.name && <InstanceDetailsAzure setStepError={setStepError} onFinish={onFinish} {...props}/>}
        {type === FM_AGENT_TYPE_GCP.name && <InstanceDetailsGcp setStepError={setStepError} onFinish={onFinish} {...props}/>}
        {type === FM_AGENT_TYPE_ONPREM.name && <InstanceDetailsOnprem onFinish={onFinish} {...props}/>}

        {stepError && <div className="instance-details-error-container">
            <NotificationError
                isNarrow={true}
                text={stepError}
                shortDescription={"Error starting deployment."}
                onClose={()=>{setStepError(null)}}/>
        </div>}
    </>);
};

const mapStateToProps = state => ({
    credentials: state.deploy.credentials //to be used by the child components
});

export default connect(mapStateToProps, {
    addNotification,
    getRelationships,
    addDeployment //to be used by the child components
})(InstanceDetails);
