import React, {useCallback} from "react";
import InstanceDetailsAwsForm from './InstanceDetailsAwsForm';
import {v4 as uuidv4} from 'uuid';
import * as awsService from "../../services/aws.api.service";
import {FM_AGENT_TYPE_AWS} from "../../consts";
import {extractErrorAws} from '../../utils/providers-utils';

const InstanceDetailsAws = ({addDeployment, dataBroker, credentials: {aws: credentials}, setStepError, onFinish}) => {
    const {id, name, fileLink} = dataBroker;
    const templateUrlEncoded = fileLink && fileLink.substr(fileLink.indexOf("https%3"));
    const templateUrl = decodeURIComponent(templateUrlEncoded);

    const handleError = useCallback((error) => setStepError(extractErrorAws(error)), [setStepError]);

    const handleDeployClick = useCallback(async (values) => {
        try {
            const deployDetails = getDeployDetails(values);
            const stackId = await startDeploy(deployDetails, name, templateUrl, credentials);
            addDeployment({
                dataBrokerId: id,
                dataBrokerName: name,
                providerType: FM_AGENT_TYPE_AWS.name,
                deployDetails: {
                    stackId,
                    credentials,
                    region: deployDetails.region
                }
            });
            onFinish();
        }

        catch (err) {
            handleError(err);
        }

    }, [credentials, id, name, addDeployment, templateUrl, handleError, onFinish]);

    return <InstanceDetailsAwsForm handleDeployClick={handleDeployClick} credentials={credentials} handleError={handleError}/>;
};

export default InstanceDetailsAws;

const getDeployDetails = ({selectedRegion, selectedVpc, selectedSubnet, publicIpStatus, selectedKeyPair, userRole}) => ({
    region: selectedRegion.value,
    vpc: selectedVpc.value,
    subnet: selectedSubnet.value,
    keyPair: selectedKeyPair.value,
    enablePublicIp: (publicIpStatus === "Disable") ? "False" : "True",
    userRole: userRole || ''
});

const startDeploy = async (deployDetails, dataBrokerName, templateUrl, credentials) => {
    const stackName = generateStackName(dataBrokerName);
    const params = [
        { ParameterKey: 'VpcId', ParameterValue: deployDetails.vpc },
        { ParameterKey: 'SubnetId', ParameterValue: deployDetails.subnet },
        { ParameterKey: 'AssociatePublicIpAddress', ParameterValue: deployDetails.enablePublicIp },
        { ParameterKey: 'KeyPair', ParameterValue: deployDetails.keyPair },
        { ParameterKey: 'UserRole', ParameterValue: deployDetails.userRole }
    ];
    const stackParams = {
        StackName: stackName,
        TemplateURL: templateUrl,
        Capabilities: ['CAPABILITY_IAM'],
        Parameters: params
    };

    try {
        const res = await awsService.deployTemplate(credentials, deployDetails.region, stackParams);
        return res.StackId;
    }
    catch (error) {
        throw new Error(extractErrorAws(error));
    }
};

const generateStackName = (dataBrokerName) => {
    return `${dataBrokerName}-${uuidv4()}`;
};
