import React, {useCallback} from "react";
import {FM_AGENT_TYPE_GCP} from '../../consts';
import ProviderLoginLayout from './ProviderLoginLayout';
import * as gcpAuthService from '../../services/gcp.auth.service';
import useRunOnce from '../../hooks/useRunOnce';

const ProviderLoginGcp = ({goToNextStep}) => {

    const doLogin = useCallback(async () => {
        if (gcpAuthService.isAuthenticated()) {
            goToNextStep();
            return;
        }
        const isLoggedIn = await authenticateWithGoogle();
        if (isLoggedIn) {
            goToNextStep();
        }
    },[goToNextStep]);

    useRunOnce(() => {
        doLogin();
    });

    return <ProviderLoginLayout
        providerDetails={FM_AGENT_TYPE_GCP}
        handleClick={doLogin}
    />
};

export default ProviderLoginGcp;

const authenticateWithGoogle = async () => {
    await gcpAuthService.init();
    return gcpAuthService.authenticate();
};
