import React from "react";
import "./providerLoginLayout.scss";
import {NotificationError} from '../notifications/NotificationItems';
import {FM_AGENT_TYPE_AWS} from '../../consts';

const ProviderLoginLayout = ({providerDetails: {providerName, company, circledIcon}, handleClick, isContinueDisabled, children, error, setError}) =>
    (<div className="data-broker-wizard-step provider-login-layout">

        {circledIcon}
        {providerName === FM_AGENT_TYPE_AWS.providerName && <>
            <div className="title">Provide AWS credentials</div>
        </>}

        {providerName !== FM_AGENT_TYPE_AWS.providerName && <>
            <div className="title">Log in to {providerName}</div>
            <p>Click <b>Continue</b> to log in to your {providerName} account using a form that is owned and hosted by {company}.
                Your credentials are not provided to NetApp.</p>
        </>}


        <div className="content-area">
            {children}
        </div>

        {error && <NotificationError
            isNarrow={true}
            text={error}
            shortDescription={"Error during login."}
            onClose={()=>{setError(null)}}/>}

        <div className="button-footer">
            <button className="button primary" type="button" onClick={handleClick} disabled={isContinueDisabled}>
                Continue
            </button>
        </div>

    </div>);

export default ProviderLoginLayout;
