import React, {Component} from "react";
import classNames from "classnames";
import Isvg from 'react-inlinesvg';
import ScrollArea from 'react-scrollbar';
import ReactDOM from 'react-dom';
require("./errorsPanel.scss");

export default class extends Component {
    toggleErrorsState() {
        this.props.toggleErrorsState();
    }

    removeError(id) {
        this.props.removeError(id);
    }

    componentDidUpdate(prevProps) {
        const {_generalErrors: {_errorsPanelSize}} = prevProps;
        const boundingClientRect = ReactDOM.findDOMNode(this).getBoundingClientRect();
        if (_errorsPanelSize.height !==  boundingClientRect.height)
            this.props.broadcastErrorsPanelSize(boundingClientRect);
    }

    componentDidMount() {
        this.props.broadcastErrorsPanelSize(ReactDOM.findDOMNode(this).getBoundingClientRect());
    }

    render() {
        const {_generalErrors: {_errors, _errorsPanelOpen}, _ui: {isCmIntegration}} = this.props;
        const isOpen = (_errors && _errors.length > 0) && _errorsPanelOpen;
        const cmErrorType = isCmIntegration ? "error" : undefined;
        const errorsContainer=  (
            <div className="errors-container clearfix">{_errors.map(error =>
                <ErrorItem error={error} key={error.id} cmErrorType={cmErrorType} remove={this.removeError.bind(this)}/>)}
            </div>
        );

        return (
            <div className={classNames("errors-panel", {"is-visible": isOpen, [cmErrorType]: cmErrorType})}>
                <div className="errors-header">
                    <div>
                         <span><Isvg src={require("./../../assets/svgs/errors-footer.svg")}/></span>
                        {_errors.length} {_errors.length === 1 ? 'Error' : 'Errors'}
                    </div>
                    <div onClick={this.toggleErrorsState.bind(this)}>
                         <span><Isvg src={require("./../../assets/svgs/errors-mimimize.svg")}/></span>
                    </div>
                </div>
                {_errors.length > 4 && <ScrollArea
                    style={{ width: "100%", height: 236 }}
                    className="area"
                    contentClassName="content"
                    verticalScrollbarStyle={{borderRadius: 0, backgroundColor: "#818483", width: "5px", position: "relative"}}
                    verticalContainerStyle={{borderRadius: 0, opacity: 1, width: "5px"}}
                    horizontal={false}
                    smoothScrolling= {true}
                    minScrollSize={35}
                    >
                    {errorsContainer}
                </ScrollArea>}
                {_errors.length <= 4 && errorsContainer}
            </div>
        )
    }

}

const ErrorItem = ({error, remove, cmErrorType}) => {
    return (
        <div className="error-item">
            <div>
                {cmErrorType && <Isvg className={`triangle ${cmErrorType}`} src={require("./../../assets/svgs/exclamation-mark-triangle-icon.svg")}/>}
                {error.message}
            </div>
            <div>
                <button onClick={() => remove(error.id)}>X</button>
            </div>

        </div>
    )
};
