import {
    getCvsWorkingEnvironments,
    closeSearchWidget,
    clearCloseSearchWidget,
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
} from '../../store/wizard/action_creators';
import React, {useMemo, useState} from 'react';
import {connect} from 'react-redux';
import stepinize from "./../wizard/stepinize";
import HowDoesItWorkButton from "./../systemFlow/HowDoesItWorkButton";
import classNames from "classnames";
import {Route, Switch} from 'react-router-dom';
import CardsContainer from '../cards/CardsContainer';
import AnfWeCard from './AnfWeCard';
import {getAnfWorkingEnvironments} from '../../utils/cvsUtils';
import useRunOnceWhenTruthy from '../../hooks/useRunOnceWhenTruthy';
import _ from "lodash";
import "./anfWeStep.scss";
import UiStatePusher from '../UiStatePusher';
import {SystemFlow} from '../systemFlow/SystemFlow';
import ButtonWithNotification from '../widgets/ButtonWithNotification';
import {buildServersList, getPropFromState, getWizardParamsFromUrlParams} from '../../utils/mapStateToPropsUtils';

const AnfWeStep = (props) => {
    const [howItWorksClosed, setHowItWorksClosed] = useState(false);
    const [selectedAnf, setSelectedAnf] = useState(null);
    const [error, setError] = useState(null);

    const { _relationships, _wizard, up, isTargetStepFromSameSourceType, _cvsWorkingEnvironments, _cmIntegration: {inputDetails}} = props;
    const {wizardTypeForSystemFlow, isSecure, stepsOrder, currentStep, isSourceStep, selectedWizardParams} = _wizard;
    const {selectedAnfWe, selectedAnfWeTarget} = selectedWizardParams;
    const {isSource, viewDashboard, workingEnvironmentType, workingEnvironmentName} = inputDetails || {};

    const theRelevantAnf = isTargetStepFromSameSourceType ? selectedAnfWeTarget : selectedAnfWe;
    const isFirstStepOfWizard = stepsOrder[0] === currentStep;
    const showHowItWorks = _relationships && _relationships.data && _relationships.data.length === 0 && !howItWorksClosed && isFirstStepOfWizard && !theRelevantAnf;

    //in case it was selected in the CM gallery
    const showOnlyCmSelection = workingEnvironmentType?.toLowerCase() === "anf" && !viewDashboard && isSource === isSourceStep;

    //"start wizard" action updates "currentStep" and "isSourceStep". Only when this is done, "isSourceStep" is up to date.
    const isSourceStepUpdated = currentStep?.toLowerCase().endsWith("anfwe");

    const anfWorkingEnvironments = useMemo(() => {
        const anfWe = getAnfWorkingEnvironments(_cvsWorkingEnvironments);
        const selectedWe = _.find(anfWe, {name: workingEnvironmentName});
        return showOnlyCmSelection ? [selectedWe] : anfWe;
    }, [_cvsWorkingEnvironments, showOnlyCmSelection, workingEnvironmentName]);

    //initialize selection:
    useRunOnceWhenTruthy(() => {
        //in case of only 1 exists
        if (anfWorkingEnvironments.length === 1) {
            setSelected(anfWorkingEnvironments[0].id);
            return;
        }
        //in case of back navigation
        if (theRelevantAnf) {
            setSelected(theRelevantAnf);
        }
    }, anfWorkingEnvironments?.length > 0 && isSourceStepUpdated);

    const handleContinue = () => {
        if (!selectedAnf) {
            setError("You need to select a working environment before you can continue.");
            return;
        }
        const nextStep = props.nextStep;
        props._wizard.nextStep(`/${selectedAnf}/${nextStep.path}`, props.history);
    };

    const setSelected = (id) => {
        if (selectedAnf !== id) {
            setSelectedAnf(id);
            setError("")
        }
    };

    const containerOptions = {singularTitle: "Working Environment", pluralTitle: "Working Environments", noWidgets: showOnlyCmSelection};
    const selectionOptions = {selector: setSelected, selectedId: selectedAnf};

    return (
        <div className="wizard-step anf-we-step">
            <div className={classNames("scrollable-area", {up, down: !up})}>
                {showHowItWorks &&
                <UiStatePusher ui="wizard no-steps">
                    <div className="how-it-works-step">
                        <h3>How It Works</h3>
                        <SystemFlow wizardType={wizardTypeForSystemFlow} isSecure={isSecure}/>
                    </div>
                </UiStatePusher>}
                {!showHowItWorks &&
                <>
                    <div className="title-and-actions">
                        <div className="actions-left">
                            <HowDoesItWorkButton wizardType={wizardTypeForSystemFlow} isSecure={isSecure}/>
                        </div>
                        <div className="title-middle">
                            <h3>{showOnlyCmSelection ? "Selected " : "Select a "}{isTargetStepFromSameSourceType ? "Target" : ""} Working Environment</h3>
                        </div>
                        <div className="actions-right"/>
                    </div>
                    {anfWorkingEnvironments &&
                    <CardsContainer
                        containerOptions={containerOptions}
                        selectionOptions={selectionOptions}
                        className="anf-working-environments"
                        Card={AnfWeCard}
                        data={anfWorkingEnvironments}
                    />}
                </>}
            </div>
            <ButtonWithNotification
                onClick={showHowItWorks ? () => {setHowItWorksClosed(true)} : handleContinue}
                error={error}
                clearError={() => setError(null)}
                text="Continue"/>
        </div>)

    };

const stepId = ({isTargetStepFromSameSourceType}) => {
    return isTargetStepFromSameSourceType ? 'targetAnfWe' : 'anfWe';
};
const willMount = (props) => {
    const {_accountInfo} = props;
    const accountId = _accountInfo?.data?.accountId;
    if (!props._cvsWorkingEnvironments || !(props._cvsWorkingEnvironments.inProgress || props._cvsWorkingEnvironments.succeeded) ){
        return props.getCvsWorkingEnvironments(accountId);
    }
};
const isFetching = ({_cvsWorkingEnvironments}) => {
    return _cvsWorkingEnvironments?.inProgress;
};

const canShowNextStep = (props) => {
    const {isTargetStepFromSameSourceType, _wizard} = props;
    return isTargetStepFromSameSourceType ? _wizard.selectedWizardParams.selectedAnfWeTarget : _wizard.selectedWizardParams.selectedAnfWe;
};

const nextRoutes = ({match, nextStep, NextStepComp, isTargetStepFromSameSourceType}) => {
    return (
        <Switch>
            {isTargetStepFromSameSourceType &&
            <Route path={`${match.url}/:anfWeTarget/${nextStep.path}`} render={(props) =>
                <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
            }/>}
            {!isTargetStepFromSameSourceType &&
            <Route path={`${match.url}/:anfWe/${nextStep.path}`} render={(props) =>
                <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
            }/>}
        </Switch>
    )
};

const mapStateToProps = (state, ownProps) => {
    return {
        _servers: buildServersList(state),
        _wizard: getWizardParamsFromUrlParams(state, ownProps),
        _cvsWorkingEnvironments:  getPropFromState(state, "_cvsWorkingEnvironments", {}),
        _relationships: getPropFromState(state, "_relationships", {}),
        _cmIntegration: state.global._cmIntegration,
        routing: state.router,
        ...ownProps
    }
};

const mapDispatchToProps = {
    getCvsWorkingEnvironments,
    closeSearchWidget,
    clearCloseSearchWidget,
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
};

export default connect(mapStateToProps, mapDispatchToProps)(stepinize(AnfWeStep, {
    stepId,
    willMount,
    isFetching,
    canShowNextStep,
    nextRoutes,
    loading: () => {
        return {
            className: 'anf-we',
            text: 'Working Environments',
            icon: require('./../../assets/svgs/anf-default.svg')
        }
    }
}));
