import React from "react";
import classNames from "classnames";
import {DEPLOY_STATUS_ERROR, DEPLOY_STATUS_PROGRESS, DEPLOY_STATUS_SUCCESS} from '../../consts';
import PopoverInfo from "../_common_/reactPopover/PopoverInfo";
import ReactLoading from 'react-loading';
import Isvg from "react-inlinesvg";
import "./brokerStatusDisplay.scss";

const BrokerStatusDisplay = ({isFailed, isDisabled, isWaiting, deployment, agentFailureMessage, disabledErrorMessage}) => {
    const status = getStatus({isFailed, isDisabled, isWaiting, deployment, agentFailureMessage, disabledErrorMessage});
    return (<div className={classNames("broker-status-display", status.type.toLowerCase())} >
        <div className="icon">{status.icon}</div>
        <div className="text">{status.text}</div>
        {status.errorMessageText && <PopoverInfo>
            {status.errorMessageText}
        </PopoverInfo>}
    </div>)
};
export default BrokerStatusDisplay;

const getStatus = ({isFailed, isDisabled, isWaiting, deployment, agentFailureMessage, disabledErrorMessage}) => {
    const isError       = isFailed || isDisabled;
    const isDeploying   = !isDisabled && isWaiting && deployment && (deployment.deployStatus === DEPLOY_STATUS_PROGRESS || deployment.deployStatus === DEPLOY_STATUS_SUCCESS);
    const isDeployError = !isDisabled && isWaiting && deployment && deployment.deployStatus === DEPLOY_STATUS_ERROR;
    const isUnknown     = !isDisabled && isWaiting && !deployment;

    let statusType;
    if (isError || isDeployError) statusType = DEPLOY_STATUS_ERROR;
    else if (isDeploying) statusType = DEPLOY_STATUS_PROGRESS;
    else if (isUnknown) statusType = "unknown";
    else statusType = DEPLOY_STATUS_SUCCESS;

    switch (statusType) {
        case DEPLOY_STATUS_ERROR: {
            return {
                type: statusType,
                text: isFailed ? "Connection Failed" : isDisabled ? "Missing credentials" : "Error",
                icon: <div className="circled"><span>!</span></div>,
                errorMessageText: isFailed ? agentFailureMessage : isDisabled ? disabledErrorMessage : ""
            }
        }
        case DEPLOY_STATUS_PROGRESS: {
            return {
                type: statusType,
                text: "Deploying",
                icon: <ReactLoading type="spin" color="#0891d8" height={0} width={20} delay={50} />
            }
        }

        case DEPLOY_STATUS_SUCCESS: {
            return {
                type: statusType,
                text: "Active",
                icon: <Isvg src={require("../../assets/svgs/checkmark-green.svg")}/>
            }
        }
        case "unknown":
        default: {
            return {
                type: statusType,
                text: "Waiting",
                icon: <Isvg src={require("../../assets/svgs/clock-icon.svg")}/>
            }
        }
    }
};