import React from 'react';
import {connect} from "react-redux";
import {FM_AGENT, FM_AGENT_TYPE_AWS, FM_AGENT_TYPE_AZURE, FM_AGENT_TYPE_GCP, FM_AGENT_TYPE_ONPREM} from "../../consts";
import {deleteDataBroker} from "../../store/wizard/action_creators";
import DialogLayout from '../dialog/DialogLayout';
import _ from "lodash";

const deleteDataBrokerDialog = ({closeDialog, data, deleteDataBroker, deployments}) => {
    const existingDeployment = _.find(deployments, {dataBrokerId: data.id});

    return (
        <DialogLayout
            title={`Remove ${FM_AGENT}`}
            closeDialog={closeDialog}
            onConfirm={() => deleteDataBroker(data.id, existingDeployment)}
            confirmButtonText="Remove Data Broker"
        >
            {!existingDeployment &&
            <p>This action only deletes the Data Broker from Cloud Sync&#39;s records. <br/>
                You need to delete
                {data.type === FM_AGENT_TYPE_AWS.name && <span> the CloudFormation Stack in AWS.</span>}
                {data.type === FM_AGENT_TYPE_AZURE.name && <span> the Virtual Machine in Azure.</span>}
                {data.type === FM_AGENT_TYPE_GCP.name && <span> the instance in GCP.</span>}
                {data.type === FM_AGENT_TYPE_ONPREM.name && <span> any additional cloud resources you created.</span>}
            </p>}

            {existingDeployment &&
            <p>This action deletes the Data Broker from Cloud Sync&#39;s records. <br/>
            Cloud Sync will also attempt to delete all the cloud resources that were created during the deployment.</p>}

            <p>Are you sure that you want to remove the {FM_AGENT} {`'${data.name}'`}?</p>

        </DialogLayout>
    );
};

const mapStateToProps = state => ({
   deployments: state.deploy.deployments
});
export default connect(mapStateToProps, {deleteDataBroker})(deleteDataBrokerDialog);