import React from 'react';
import Isvg from 'react-inlinesvg';
import { DraggableTypes} from "../../consts";
import {DragSource} from "react-dnd";

const draggableEndPoint = {
    beginDrag(props) {
        return {endPointName: props.title};
    },
    endDrag(props, monitor) {
        if (!monitor.didDrop()) {
            return;
        }
        const { onDrop } = props;
        const { endPointName } = monitor.getItem();
        const { dropEndPoint } = monitor.getDropResult();
        onDrop(endPointName, dropEndPoint);
    },
    canDrag(props) {
        return props.isAllowed;
    }
};

function collect(connect, monitor) {
    return {
        connectDragSource: connect.dragSource(),
        isDragging: monitor.isDragging()
    }
}

const DraggableEndPoint = ({icon, disabledIcon, connectDragSource, isDragging, isAllowed, title}) => {
    //Note: both svgs exists in advanced (only their display changes) in order to have them loaded when the step loads
    // This is to prevent a "jump" in UI when endpoint is dragged and svg load occurs.
    return connectDragSource(
        <div className="end-point" title={title} style={{
            cursor: !isAllowed ? "auto" : "move"
        }}>
           <Isvg className={`${(isDragging || !isAllowed) ? "hidden" : ""}`} src={icon}/>
           <Isvg className={`${(!isDragging && isAllowed) ? "hidden" : ""}`} src={disabledIcon}/>
        </div>
    )
};


export default DragSource(DraggableTypes.END_POINT, draggableEndPoint, collect)(DraggableEndPoint);