import React, {Component} from 'react';
import stepinize from "./../wizard/stepinize";
import {connect} from 'react-redux';
import {RelationshipTagsForm} from "./RelationshipTagsForm";
import {stringToTags, tagsToString} from "../../utils/helpers";
import {encodeAll} from "../../utils/encoders";
import {Route, Switch} from 'react-router-dom';
import {getSettingsFromSessionStorage} from '../../utils/settings-utils';
import {getWizardParamsFromUrlParams} from '../../utils/mapStateToPropsUtils';
import _ from "lodash";
import {
    updateUrlParams,
    wizardStepExited,
    wizardStepStarted
} from '../../store/wizard/action_creators';

require("./relationshipTags.scss");

class RelationshipTagsStep extends Component {
    continue(values) {
        this.props._wizard.nextStep(`/${encodeAll(tagsToString(values.tags))}/review`, this.props.history);
    }

    render() {
        const { _wizard: {wizardTypeForSystemFlow, isSecure, wizardInfo, selectedWizardParams: {relationshipTags}}, up} = this.props;

        const settings = getSettingsFromSessionStorage();
        const objectTaggingDisabled = !(_.get(settings, 'objectTagging', true));
        const initialTags = relationshipTags && relationshipTags !== "noTags" ? stringToTags(relationshipTags) : [{key:"", value:""}];
        return (
            <div className="wizard-step relationship-tags-step">
                <RelationshipTagsForm
                    complete={this.continue.bind(this)}
                    initialTags={initialTags}
                    targetProtocol={wizardInfo.target.protocol}
                    objectTaggingDisabled={objectTaggingDisabled}
                    isSecure={isSecure}
                    wizardInfo={wizardInfo}
                    up={up}
                    wizardTypeForSystemFlow={wizardTypeForSystemFlow}/>
            </div>
        )
    }
}

const canShowNextStep = ({_wizard: {selectedWizardParams: {relationshipTags}}}) => {
    return relationshipTags;
};

const nextRoutes = ({match, nextStep, NextStepComp}) => {
    return (
        <Switch>
            <Route path={`${match.url}/:relationshipTags/${nextStep.path}`} render={(props) =>
                <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
            }/>
        </Switch>
    )
};

const mapStateToProps = (state, ownProps) => {
    return {
        _wizard: getWizardParamsFromUrlParams(state, ownProps),
        routing: state.router,
        ...ownProps
    }
};

const mapDispatchToProps = {
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
};

export default connect(mapStateToProps, mapDispatchToProps)(stepinize(RelationshipTagsStep, {stepId: () => "relationshipTags", willMount: null, isFetching: null, canShowNextStep, nextRoutes}));