import React, {Component} from 'react';
import {
    azureSelectStep,
    showAzureBlobContainers,
    listAzureBlobContainerFolders,
    azureAdditionalStorageSettingsStep,
    clearFoldersCache,
    closeSearchWidget,
    clearCloseSearchWidget,
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
} from '../../store/wizard/action_creators';
import {connect} from 'react-redux';
import stepinize from "./../wizard/stepinize";
import TagsPopover from "./../widgets/TagsPopover";
import {formValueSelector, reduxForm} from 'redux-form';
import {Route, Switch} from 'react-router-dom';
import ShowObjectStorageStepTemplate from "./ShowObjectStorageStepTemplate";
import {AZURE_BLOB_TIER_OPTIONS, DEFAULT_AZURE_BLOB_TIER} from '../../consts';
import AdditionalAzureBlobSettingsUI from './additionalAzureBlobSettings/AdditionalAzureBlobSettingsUI';
import _ from "lodash";
import {getPropFromState, getWizardParamsFromUrlParams} from '../../utils/mapStateToPropsUtils';

require("./showObjectStorageStep.scss");

class ShowAzureBlobContainersStep extends Component{
    constructor(props) {
        super(props);
        const {_wizard: {selectedWizardParams: {selectedBlobTier}}} = this.props;
        this.state = {
            blobTier: selectedBlobTier
        };
    }
    callListAzureBlobContainerFolders(dataBrokerId, container, path){
        const {listAzureBlobContainerFolders, isTargetStepFromSameSourceType, _wizard: {selectedWizardParams: {selectedStorageAccountName, selectedStorageAccountNameTarget}}} = this.props;
        const actualStorageAccountName = isTargetStepFromSameSourceType ? selectedStorageAccountNameTarget : selectedStorageAccountName;
        listAzureBlobContainerFolders(dataBrokerId, actualStorageAccountName, container, path, isTargetStepFromSameSourceType);

    }

    static innerColumns(row) {
        const {tags} = row;
        return tags ? [
            <td className="path" key="path">
                <div className="text" title={row.path}>{row.path}</div>
                <div className="title">Name</div>
            </td>,
            <TagsPopover tags={tags} inTable={true} leftAdjust={-470} key="tags"/>,
        ] : [<td className="path" title={row.path} key="path">{row.path}</td>];
    }

    returnToBucketsStep() {
        this.setState(Object.assign({}, this.state, {blobTier: DEFAULT_AZURE_BLOB_TIER}));
        const {change} = this.props;
        change("blobTier", DEFAULT_AZURE_BLOB_TIER);
        this.props.azureSelectStep();
    }

    changeBlobTierSelection(selectedOptions) {
        this.setState(Object.assign({}, this.state, {blobTier: selectedOptions.value}));

    }

    getSecondStepUi(step, bucketPath) {
        if (!bucketPath) return <div/>;
        return <AdditionalAzureBlobSettingsUI step={step} bucketPath={bucketPath}
                                     isSourceStep={this.props._wizard.isSourceStep}
                                     handleClose={this.returnToBucketsStep.bind(this)}
                                     selectedBlobTier={this.state.blobTier || DEFAULT_AZURE_BLOB_TIER}
                                     blobTierOptions={AZURE_BLOB_TIER_OPTIONS}
                                     handleBlobTierSelection={this.changeBlobTierSelection.bind(this)}/>
    }

    setAdditionalSettings(step) {
        if (step === "select" && !this.props._wizard.isSourceStep) {
            this.props.azureAdditionalStorageSettingsStep();
            return false;
        }
        else {
            return true;
        }
    }

    render(){
        const {clearFoldersCache, _showAzureBlobContainers, _wizard: {selectedWizardParams: {selectedAzureBlobContainerPath, selectedAzureBlobContainerPathTarget, selectedStorageAccountName, selectedStorageAccountNameTarget}}, isTargetStepFromSameSourceType, _ui: {azure}} = this.props;

        const actualStorageAccountName = isTargetStepFromSameSourceType? selectedStorageAccountNameTarget : selectedStorageAccountName;
        const azureBlobContainersForStorageAccount = _showAzureBlobContainers[actualStorageAccountName];

        const containerOptions = {
            singularTitle: "Container",
            pluralTitle: "Containers",
            itemIdentifier: "actualPath",
            rootName: "All Containers",
            targetName: "Define Target Directory",
            directoriesName: "Directories",
            directoryName: "directory",
            icon: require("./../../assets/svgs/bucket-icon.svg"),
            nameForSetupStep: "Blob Setup"
        };

        const step = azure && azure.step && azure.step === "additionalSettings" ? "secondStep" : "select";
        const stepOptions = {
            selectedBaseObject: isTargetStepFromSameSourceType ? selectedAzureBlobContainerPathTarget : selectedAzureBlobContainerPath,
            title: "Select a Container",
            failedMessage: "Unable to retrieve containers",
            notFoundMessage: "No containers were found",
            bottomMessage: "in your Azure Storage Account",
            storage: azureBlobContainersForStorageAccount,
            getStorageByBrokerId: false,
            listSubFoldersAction: this.callListAzureBlobContainerFolders.bind(this),
            storageObjectName: "Conatiner",
            storageObjectType: "Azure Blob",
            innerColumns: ShowAzureBlobContainersStep.innerColumns,
            stepFormName: "azureBlobContainersForm",
            containerOptions,
            supportAddStorageObject: false,
            innerPathBeginWithSlash: false,
            getSecondStepUi: this.getSecondStepUi.bind(this),
            updateStepInfo: this.setAdditionalSettings.bind(this),
            currentStep: step,
            extraUrlParam: this.state.blobTier || DEFAULT_AZURE_BLOB_TIER,
            resetToFirstStepAction: this.props.azureSelectStep,
            refreshStep:() => {clearFoldersCache({cacheName:"_showAzureBlobContainers", storageKey:actualStorageAccountName}) ;fetchAzureBlobContainers(this, this.props)}
        };

        return <ShowObjectStorageStepTemplate stepOptions={stepOptions} {...this.props}/>;
    }
}

const fetchAzureBlobContainers = (localThis, props) => {
    const {isTargetStepFromSameSourceType} = props;
    const localSelectedStorageAccountProp = isTargetStepFromSameSourceType ? localThis.props._wizard.selectedWizardParams.selectedStorageAccountNameTarget: localThis.props._wizard.selectedWizardParams.selectedStorageAccountName;
    return props.showAzureBlobContainers(localThis.props._wizard.selectedWizardParams.selectedDataBroker.id, localSelectedStorageAccountProp, isTargetStepFromSameSourceType);
};

const willMount = (props, currentThis) => {
    const {_showAzureBlobContainers, _wizard :{selectedWizardParams: {selectedStorageAccountName, selectedStorageAccountNameTarget, selectedDataBroker}},isTargetStepFromSameSourceType} = props;
    const actualStorageAccountName = isTargetStepFromSameSourceType? selectedStorageAccountNameTarget : selectedStorageAccountName;
    const azureBlobContainersForStorageAccount = (_showAzureBlobContainers[actualStorageAccountName] && _showAzureBlobContainers[actualStorageAccountName].dataBrokerId ===  _.get(selectedDataBroker, 'id')) ?
        _showAzureBlobContainers[actualStorageAccountName] : undefined;
    if (!azureBlobContainersForStorageAccount || azureBlobContainersForStorageAccount.failedRetrieve) {
        if (!props._wizard.selectedWizardParams.selectedDataBroker || !actualStorageAccountName) {
            setTimeout(fetchAzureBlobContainers.bind(this, currentThis, props), 200);
        }
        else fetchAzureBlobContainers.bind(this, currentThis, props)();
    }
};
const stepId = ({isTargetStepFromSameSourceType}) => {
    return isTargetStepFromSameSourceType ? "targetBlobContainers" : "blobContainers";
};

const isFetching = (props) => {
    const {_showAzureBlobContainers, _wizard: {selectedWizardParams: {selectedStorageAccountName, selectedStorageAccountNameTarget}}, isTargetStepFromSameSourceType} = props;
    const actualStorageAccountName = isTargetStepFromSameSourceType? selectedStorageAccountNameTarget : selectedStorageAccountName;
    const azureBlobContainersForStorageAccount = _showAzureBlobContainers[actualStorageAccountName];
    if (!azureBlobContainersForStorageAccount) return true;
    return azureBlobContainersForStorageAccount.inProgress  ||  ((!azureBlobContainersForStorageAccount.data || azureBlobContainersForStorageAccount.data.length === 0) && !azureBlobContainersForStorageAccount.retrievedAll);

};
const canShowNextStep = (props) => {
    const {_showAzureBlobContainers, _wizard: {selectedWizardParams: {selectedStorageAccountName, selectedStorageAccountNameTarget, selectedAzureBlobContainerPath, selectedAzureBlobContainerPathTarget}}, isTargetStepFromSameSourceType} = props;
    const actualStorageAccountName = isTargetStepFromSameSourceType? selectedStorageAccountNameTarget : selectedStorageAccountName;
    const azureBlobContainersForStorageAccount = _showAzureBlobContainers[actualStorageAccountName];
    if (!azureBlobContainersForStorageAccount) return false;
    const actualAzureBlobContainerPath = isTargetStepFromSameSourceType ? selectedAzureBlobContainerPathTarget : selectedAzureBlobContainerPath;
    return azureBlobContainersForStorageAccount.succeeded && azureBlobContainersForStorageAccount.data && azureBlobContainersForStorageAccount.data.length > 0 && actualAzureBlobContainerPath;
};
const nextRoutes = ({match, isTargetStepFromSameSourceType, nextStep, NextStepComp, isSourceStep}) => {

    return (
        <Switch>
            {isSourceStep &&
                <Route path={`${match.url}/:azureBlobContainerPath/${nextStep.path}`} render={(props) =>
                    <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
                }/>}
            {!isSourceStep && isTargetStepFromSameSourceType &&
                <Route path={`${match.url}/:azureBlobContainerPathTarget/:blobTierTarget/${nextStep.path}`} render={(props) =>
                    <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
                }/>}
            {!isSourceStep && !isTargetStepFromSameSourceType &&
                <Route path={`${match.url}/:azureBlobContainerPath/:blobTier/${nextStep.path}`} render={(props) =>
                    <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
                }/>}
        </Switch>
    )
};


let AzureBlobContainersForm = reduxForm({form: 'azureBlobContainersForm'})(ShowAzureBlobContainersStep);
const selector = formValueSelector('azureBlobContainersForm');
AzureBlobContainersForm = connect(
    (state) => ({
        blobTier: selector(state, "blobTier")
    })
)(AzureBlobContainersForm);

const mapStateToProps = (state, ownProps) => {
    return {
        _wizard: getWizardParamsFromUrlParams(state, ownProps),
        _showAzureBlobContainers:  getPropFromState(state, "_showAzureBlobContainers", {}),
        _ui: {...state.syncReducer._ui, ...state.global._ui},
        routing: state.router,
        ...ownProps
    }
};

const mapDispatchToProps = {
    showAzureBlobContainers,
    listAzureBlobContainerFolders,
    azureSelectStep,
    azureAdditionalStorageSettingsStep,
    clearFoldersCache,
    closeSearchWidget,
    clearCloseSearchWidget,
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
};

export default connect(mapStateToProps, mapDispatchToProps)(stepinize(AzureBlobContainersForm, {stepId, willMount, isFetching, canShowNextStep, nextRoutes,
    loading: () => {return {text: "Containers", icon: require("./../../assets/svgs/azure-default.svg")}}}));
