import React, {Component} from 'react';
import {
    showBuckets,
    listBucketFolders,
    addNewBucket,
    bucketsSelectStep,
    bucketsEncryptionStep,
    listAwsKmsKeys,
    clearFoldersCache,
    closeSearchWidget,
    clearCloseSearchWidget,
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
} from '../../store/wizard/action_creators';
import {connect} from 'react-redux';
import stepinize from "./../wizard/stepinize";
import {getFormValues, reduxForm} from 'redux-form';
import {Route, Switch} from 'react-router-dom';
import ShowBucketsStepBase from "./ShowBucketsStepBase";
import Validator from 'validatorjs';
import _ from 'lodash';
import {ENCRYPTION_TYPES} from '../../consts';
import {getPropFromState, getWizardParamsFromUrlParams} from '../../utils/mapStateToPropsUtils';

const rules = encryptionTypeOption => {
    const rules = {
        encryptionTypeOption: 'required'
    };

    if (encryptionTypeOption?.value === ENCRYPTION_TYPES.KMS_EXISTING) {
        rules.encryptionKeyOption = 'required';
    }
    if (encryptionTypeOption?.value === ENCRYPTION_TYPES.KMS_MANUAL) {
        rules.encryptionKeyManual = 'required';
    }
    return rules;
};

const shouldValidate = ({values, nextProps, props, initialRender}) => {
    const {_ui: {s3}} = props;
    const step = s3 ? s3.step : "select";
    return (
        initialRender ||
        (step === "encryption" && values.encryptionOn === nextProps.values.encryptionOn)
    );
};

const validate = values => {
    if ((!_.has(values, "encryptionOn") || !values.encryptionOn))
        return;
    const {encryptionTypeOption} = values;
    const validator = new Validator(values, rules(encryptionTypeOption));
    validator.setAttributeNames({
        encryptionTypeOption: 'Encryption Type',
        encryptionKeyManual: 'Encryption Key',
        encryptionKeyOption: 'Encryption Key'
    });
    validator.passes();
    return validator.errors.all();
};

class ShowBucketsStep extends Component {
    render() {
        return <ShowBucketsStepBase {...this.props} fetchBuckets={() => fetchBuckets(this, this.props)}/>;
    }
}

const stepId = ({isTargetStepFromSameSourceType}) => {
    return isTargetStepFromSameSourceType ? 'targetS3Buckets' : 's3Buckets';
};

const fetchBuckets = (localThis, props) => props.showBuckets(localThis.props._wizard.selectedWizardParams.selectedDataBroker.id);

const willMount = (props, currentThis) => {
    const {_showBuckets, _wizard :{selectedWizardParams: {selectedDataBroker}}} = props;
    const showBuckets = _showBuckets[_.get(selectedDataBroker, 'id')];
    if (!showBuckets || showBuckets.failedRetrieve) {
        if (!selectedDataBroker)
            setTimeout(fetchBuckets.bind(this, currentThis, props), 200);
        else fetchBuckets.bind(this, currentThis, props)();
    }
};
const isFetching = (props) => {
    const {_showBuckets, _wizard: { selectedWizardParams: {selectedDataBroker}}} = props;
    const bucketsByBrokerId = _showBuckets[selectedDataBroker.id];
    return !bucketsByBrokerId || bucketsByBrokerId.inProgress || ((!bucketsByBrokerId.data || bucketsByBrokerId.data.length === 0) && !bucketsByBrokerId.retrievedAll);
};


const canShowNextStep = (props) => {
    const {_showBuckets, _wizard: {selectedWizardParams: {selectedDataBroker}}} = props;
    const bucketsByBrokerId = _showBuckets[selectedDataBroker.id];
    const theRelevantSelected = props.isTargetStepFromSameSourceType ? props._wizard.selectedWizardParams.selectedBucketPathTarget : props._wizard.selectedWizardParams.selectedBucketPath;
    return bucketsByBrokerId && bucketsByBrokerId.succeeded && bucketsByBrokerId.data && bucketsByBrokerId.data.length > 0 && theRelevantSelected;
};

const nextRoutes = ({match, isSourceStep, isTargetStepFromSameSourceType, nextStep, NextStepComp}) => {
    return (
        <Switch>
            {isSourceStep &&
                <Route path={`${match.url}/:bucketPath/${nextStep.path}`} render={(props) =>
                    <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
                }/>}
            {!isSourceStep && isTargetStepFromSameSourceType &&
                <Route path={`${match.url}/:bucketPathTarget/:storageClass/:encryptionType/${nextStep.path}`} render={(props) =>
                    <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
                }/>}
            {!isSourceStep && !isTargetStepFromSameSourceType &&
            <Route path={`${match.url}/:bucketPath/:storageClass/:encryptionType/${nextStep.path}`} render={(props) =>
                <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
            }/>}
        </Switch>
    )
};


let BucketsForm = reduxForm({form: "bucketsForm", validate, shouldValidate})(ShowBucketsStep);
BucketsForm = connect(
    state => ({formValues: getFormValues("bucketsForm")(state)})
)(BucketsForm);

const mapStateToProps = (state, ownProps) => {
    return {
        _wizard: getWizardParamsFromUrlParams(state, ownProps),
        _showBuckets:  getPropFromState(state, "_showBuckets", {}),
        _ui: {...state.syncReducer._ui, ...state.global._ui},
        routing: state.router,
        ...ownProps
    }
};

const mapDispatchToProps = {
    showBuckets,
    listBucketFolders,
    addNewBucket,
    bucketsSelectStep,
    bucketsEncryptionStep,
    listAwsKmsKeys,
    clearFoldersCache,
    closeSearchWidget,
    clearCloseSearchWidget,
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
};

export default connect(mapStateToProps, mapDispatchToProps)(stepinize(BucketsForm, {
    stepId,
    willMount,
    isFetching,
    canShowNextStep,
    nextRoutes,
    loading: () => {
        return {text: "Buckets", icon: require("./../../assets/svgs/s3-default.svg")}
    }
}));
