import React from 'react';
import TagsPopover from "./../widgets/TagsPopover";
import _ from "lodash";
import {appendItemToLocalStorage} from "../../utils/sync-utils";
import {STORAGE_CLASS_OPTIONS, DEFAULT_STORAGE_CLASS, ENCRYPTION_TYPES, ENCRYPTION_TYPES_NAMES} from '../../consts';
import ShowObjectStorageStepTemplate from "./ShowObjectStorageStepTemplate";
import EncryptionSettingsUI from "./encryptionSettings/EncryptionSettingsUI";
import "./showObjectStorageStep.scss";


const ShowBucketsStepBase = (props) => {
    const {
        change, formValues, isTargetStepFromSameSourceType,
        _wizard: {isSourceStep, selectedWizardParams: {selectedBucketPath, selectedBucketPathTarget, selectedStorageClass, selectedEncryptionType, selectedDataBroker}},
        clearFoldersCache, _showBuckets, listBucketFolders, _ui: {s3}
    } = props;

    const addEncryptionKey = (bucketFullPath, key) => {
        if (!_.isEmpty(bucketFullPath))
            appendItemToLocalStorage("s3", bucketFullPath.split("/")[0], key);
    };

    const setEncryption = (step, bucketFolderFullPath) => {
        const bucketName = bucketFolderFullPath.split("/")[0];
        if (isSourceStep) return true;
        if (step === "select") {
            props.bucketsEncryptionStep();
            const bucketInfo = _.find(_showBuckets[selectedDataBroker.id].data, {name: bucketName});
            if (!bucketInfo.kmsKeys) {
                props.listAwsKmsKeys(selectedDataBroker.id, bucketName);
            }
            return false;
        } else {
            const ecKey = formValues?.encryptionTypeOption?.value === ENCRYPTION_TYPES.KMS_EXISTING
                ? formValues.encryptionKeyOption?.value
                : formValues?.encryptionKeyManual;
            addEncryptionKey(bucketFolderFullPath, ecKey);
            return true;
        }
    };

    const returnToBucketsStep = () => {
        change("encryptionOn", false);
        change("encryptionTypeOption", null);
        change("encryptionKeyOption", null);
        change("encryptionKeyManual", "");
        change("storageClass", DEFAULT_STORAGE_CLASS);
        props.clearUrlParamsIfChanged(null, null, "storageClass", null, true);
        props.clearUrlParamsIfChanged(null, null, "encryptionType", null, true);
        props.bucketsSelectStep();
    };

    const getSecondStepUi = (step, bucketPath) => {
        if (!bucketPath) return <div/>;
        const bucketInfo = _.find(_showBuckets[selectedDataBroker.id].data, {name: bucketPath});
        const kmsKeysOptions = _.chain(bucketInfo.kmsKeys)
            .map(key => ({label: key.name, value: key.arn, disabled: !key.isEnabled, disabledTitle: "Key is disabled"}))
            .value();

        return <EncryptionSettingsUI step={step} bucketPath={bucketPath}
                                     bucketInfo={bucketInfo}
                                     selectedEncryptionType={selectedEncryptionType}
                                     selectedStorageClass={selectedStorageClass}
                                     change={change}
                                     formValues={props.formValues}
                                     isSourceStep={props._wizard.isSourceStep}
                                     handleClose={returnToBucketsStep.bind(this)}
                                     storageClassOptions={STORAGE_CLASS_OPTIONS}
                                     kmsKeysOptions={kmsKeysOptions}/>
    };

    const step = s3?.step === "encryption" ? "secondStep" : "select";

    const stepOptions = {
        selectedBaseObject: isTargetStepFromSameSourceType ? selectedBucketPathTarget : selectedBucketPath,
        title: "Select a Bucket",
        resetToFirstStepAction: props.bucketsSelectStep,
        failedMessage: "Unable to retrieve buckets",
        notFoundMessage: "No buckets were found",
        bottomMessage: "in your AWS account",
        storage: _showBuckets,
        getStorageByBrokerId: true,
        listSubFoldersAction: listBucketFolders,
        storageObjectName: "Bucket",
        storageObjectType: "S3",
        innerColumns,
        stepFormName: "bucketsForm",
        currentStep: step,
        containerOptions,
        getSecondStepUi: getSecondStepUi.bind(this),
        updateStepInfo: setEncryption.bind(this),
        extraUrlParam: `${formValues?.storageClass?.value || DEFAULT_STORAGE_CLASS}/${formValues?.encryptionOn ? formValues?.encryptionTypeOption?.name : ENCRYPTION_TYPES_NAMES.NONE}`,
        supportAddStorageObject: true,
        innerPathBeginWithSlash: true,
        refreshStep: () => {
            clearFoldersCache({cacheName: "_showBuckets", storageKey: selectedDataBroker.id});
            props.fetchBuckets()
        }
    };

    return <ShowObjectStorageStepTemplate
        stepOptions={stepOptions} {...props}/>;

};

export default ShowBucketsStepBase;

const innerColumns = (row) => {
    const {region, tags, wasAddedManually} = row;
    const regionDisplay = wasAddedManually ? '' : (_.get(region, "name") ? `${region.displayName}|${region.name}` : "");
    const tagsDisplay = wasAddedManually ? <td className="tags"/> :
        (tags ? <TagsPopover tags={tags} inTable={true} leftAdjust={-470} key="tags"/> : '');

    return region && tags ? [
        <td className="path" key="path">
            <div className="text" title={row.path}>{row.path}</div>
            <div className="title">Name</div>
        </td>,
        <td className="region" key="region">
            {regionDisplay && <div className="text">{regionDisplay}</div>}
            {regionDisplay && <div className="title">Region</div>}
        </td>,
        tagsDisplay,
    ] : [<td className="path" title={row.path} key="path">{row.path}</td>];
};

const containerOptions = {
    singularTitle: "Bucket",
    pluralTitle: "Buckets",
    itemIdentifier: "actualPath",
    rootName: "All Buckets",
    targetName: "Define Target Folder",
    directoriesName: "Folders",
    directoryName: "folder",
    icon: require("./../../assets/svgs/bucket-icon.svg"),
    nameForSetupStep: "Bucket Setup"
};
