import React, {Component} from 'react';
import {
    listGCPBucketFolders,
    showGCPBuckets,
    clearFoldersCache,
    closeSearchWidget,
    clearCloseSearchWidget,
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
} from '../../store/wizard/action_creators';
import {connect} from 'react-redux';
import stepinize from "./../wizard/stepinize";
import TagsPopover from "./../widgets/TagsPopover";
import {reduxForm} from 'redux-form';
import {Route, Switch} from 'react-router-dom';
import ShowObjectStorageStepTemplate from "./ShowObjectStorageStepTemplate"
import {END_POINT_NAMES_MAP} from "../../consts";
import _ from 'lodash';
import {getPropFromState, getWizardParamsFromUrlParams} from '../../utils/mapStateToPropsUtils';

require("./showObjectStorageStep.scss");

class ShowGCPBucketsStep extends Component{
    static innerColumns(row) {
        const {region, tags} = row;
        const regionDisplay = _.get(region, 'name') ? `${region.displayName}|${region.name}` : "";
        return region && tags ? [
            <td className="path" key="path">
                <div className="text" title={row.path}>{row.path}</div>
                <div className="title">Name</div>
            </td>,
            <td className="region" key="region">
                {regionDisplay && <div className="text">{regionDisplay}</div>}
                {regionDisplay && <div className="title">Region</div>}
            </td>,
            <TagsPopover tags={tags} inTable={true} leftAdjust={-470} key="tags"/>,
        ] : [<td className="path" title={row.path} key="path">{row.path}</td>];
    }

    callListGCPBucketFoldersAction(dataBrokerId, bucket, path) {
        const {listGCPBucketFolders} = this.props;
        listGCPBucketFolders(dataBrokerId, bucket, path);
    }

    render(){
        const {clearFoldersCache, _showGCPBuckets, _wizard: {selectedWizardParams: {selectedGCPBucketPath, selectedGCPBucketPathTarget, selectedDataBroker}}, isTargetStepFromSameSourceType} = this.props;

        const containerOptions = {
            singularTitle: "Bucket",
            pluralTitle: "Buckets",
            itemIdentifier: "actualPath",
            rootName: "All Buckets",
            targetName: "Define Target Folder",
            directoriesName: "Folders",
            directoryName: "folder",
            icon: require("./../../assets/svgs/bucket-icon.svg")
        };


        const stepOptions = {
            selectedBaseObject: isTargetStepFromSameSourceType ? selectedGCPBucketPathTarget : selectedGCPBucketPath,
            title: "Select a Bucket",
            failedMessage: "Unable to retrieve buckets",
            notFoundMessage: "No buckets were found",
            bottomMessage: `in your ${END_POINT_NAMES_MAP.GCP}`,
            storage: _showGCPBuckets,
            getStorageByBrokerId: true,
            listSubFoldersAction: this.callListGCPBucketFoldersAction.bind(this),
            storageObjectName: "Bucket",
            storageObjectType: END_POINT_NAMES_MAP.GCP,
            innerColumns: ShowGCPBucketsStep.innerColumns,
            stepFormName: "gcpBucketsForm",
            containerOptions,
            supportAddStorageObject: false,
            innerPathBeginWithSlash: true,
            refreshStep:()=> {clearFoldersCache({cacheName:'_showGCPBuckets',storageKey:selectedDataBroker.id}); fetchGCPBuckets(this, this.props)}
        };

        return <ShowObjectStorageStepTemplate stepOptions={stepOptions} {...this.props}/>;
    }
}

const stepId = ({isTargetStepFromSameSourceType}) => {
    return isTargetStepFromSameSourceType ? 'targetGcpBuckets' : 'gcpBuckets';
};

const fetchGCPBuckets = (localThis, props) => localThis.props.showGCPBuckets(props._wizard.selectedWizardParams.selectedDataBroker.id);

const willMount = (props, currentThis) => {
    const {_showGCPBuckets, _wizard :{selectedWizardParams: {selectedDataBroker}}} = props;
    const showGCPBuckets = _showGCPBuckets[_.get(selectedDataBroker, 'id')];
    if (!showGCPBuckets || showGCPBuckets.failedRetrieve) {
        if (!props._wizard.selectedWizardParams.selectedDataBroker)
            setTimeout(fetchGCPBuckets.bind(this, currentThis, props), 200);
        else fetchGCPBuckets.bind(this, currentThis, props)();
    }
};
const isFetching = (props) => {
    const {_showGCPBuckets, _wizard :{selectedWizardParams: {selectedDataBroker}}} = props;
    const gcpStorageBasedOnDataBroker = _showGCPBuckets[selectedDataBroker.id];
    return !gcpStorageBasedOnDataBroker || gcpStorageBasedOnDataBroker.inProgress  ||  ((!gcpStorageBasedOnDataBroker.data || gcpStorageBasedOnDataBroker.data.length === 0) && !gcpStorageBasedOnDataBroker.retrievedAll);
};
const canShowNextStep = (props) => {
    const {_showGCPBuckets, _wizard :{selectedWizardParams: {selectedDataBroker}}} = props;
    const gcpStorageBasedOnDataBroker = _showGCPBuckets[selectedDataBroker.id];
    const theRelevantSelected = props.isTargetStepFromSameSourceType ? props._wizard.selectedWizardParams.selectedGCPBucketPathTarget : props._wizard.selectedWizardParams.selectedGCPBucketPath;
    return gcpStorageBasedOnDataBroker && gcpStorageBasedOnDataBroker.succeeded && gcpStorageBasedOnDataBroker.data && gcpStorageBasedOnDataBroker.data.length > 0 && theRelevantSelected;
};
const nextRoutes = ({match, isTargetStepFromSameSourceType, nextStep, NextStepComp}) => {
    return (
        <Switch>
            {isTargetStepFromSameSourceType && <Route path={`${match.url}/:gcpBucketPathTarget/${nextStep.path}`} render={(props) =>
                <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
            }/>}
            {!isTargetStepFromSameSourceType && <Route path={`${match.url}/:gcpBucketPath/${nextStep.path}`} render={(props) =>
                <NextStepComp {...props} isTargetStepFromSameSourceType={nextStep.isTargetStepFromSameSourceType}/>
            }/>}

        </Switch>
    )
};

const GCPBucketsForm = reduxForm({form: 'gcpBucketsForm'})(ShowGCPBucketsStep);

const mapStateToProps = (state, ownProps) => {
    return {
        _wizard: getWizardParamsFromUrlParams(state, ownProps),
        _showGCPBuckets:  getPropFromState(state, "_showGCPBuckets", {}),
        _ui: {...state.syncReducer._ui, ...state.global._ui},
        routing: state.router,
        ...ownProps
    }
};

const mapDispatchToProps = {
    listGCPBucketFolders,
    showGCPBuckets,
    clearFoldersCache,
    closeSearchWidget,
    clearCloseSearchWidget,
    updateUrlParams,
    wizardStepStarted,
    wizardStepExited
};

export default connect(mapStateToProps, mapDispatchToProps)(stepinize(GCPBucketsForm, {stepId, willMount, isFetching, canShowNextStep, nextRoutes,
    loading: () => {return {text: "Buckets", icon: require("./../../assets/svgs/gcp-default.svg")}}}));
