import React from 'react';
import {SelectField, InputField} from '../../_common_/forms/forms';
import Toggle from '../../_common_/forms/Toggle';
import Isvg from 'react-inlinesvg';
import {Field} from 'redux-form';
import {ENCRYPTION_OPTIONS, ENCRYPTION_TYPES, ENCRYPTION_TYPES_NAMES, DEFAULT_STORAGE_CLASS, STORAGE_CLASS_OPTIONS} from '../../../consts'
import _ from 'lodash';
import {getS3EncryptionKey} from '../../../utils/sync-utils';
import useRunOnceWhenTruthy from '../../../hooks/useRunOnceWhenTruthy';
import useRunOnce from '../../../hooks/useRunOnce';


const useInitializeEncryption = (encryptionOn, selectedEncryptionType, bucketKmsKeys, bucketPath, change, kmsKeysOptions, selectedStorageClass) => {

    useRunOnce(() => {
        const isEncryptionOn = selectedEncryptionType ? selectedEncryptionType !== ENCRYPTION_TYPES_NAMES.NONE : false;
        change("storageClass", STORAGE_CLASS_OPTIONS.find(option => option.value === (selectedStorageClass || DEFAULT_STORAGE_CLASS)));
        change("encryptionOn", isEncryptionOn);
    });

    useRunOnceWhenTruthy(() => {
        if (selectedEncryptionType === ENCRYPTION_TYPES_NAMES.AES) {
            change('encryptionTypeOption', _.find(ENCRYPTION_OPTIONS, {value: ENCRYPTION_TYPES.AES}));
        }
    }, selectedEncryptionType);

    useRunOnceWhenTruthy(() => {
        if (selectedEncryptionType === ENCRYPTION_TYPES_NAMES.KMS) {
            const keyFromStorage = getS3EncryptionKey(bucketPath);
            const existingKey = _.find(bucketKmsKeys, {arn: keyFromStorage});
            const encryptionKmsType = existingKey ? ENCRYPTION_TYPES.KMS_EXISTING : ENCRYPTION_TYPES.KMS_MANUAL;
            change('encryptionTypeOption', _.find(ENCRYPTION_OPTIONS, {value: encryptionKmsType}));

            //update key in form
            if (encryptionKmsType === ENCRYPTION_TYPES.KMS_EXISTING) {
                change('encryptionKeyOption', _.find(kmsKeysOptions, {value: keyFromStorage}))
            }
            if (encryptionKmsType === ENCRYPTION_TYPES.KMS_MANUAL) {
                change('encryptionKeyManual', keyFromStorage);
            }
        }
    }, bucketKmsKeys)
};


export default (props) => {
    const {formValues, change, step, isSourceStep, bucketPath, bucketInfo, handleClose, storageClassOptions, kmsKeysOptions, selectedEncryptionType, selectedStorageClass} = props;
    const encryptionOn = formValues?.encryptionOn;
    const encryptionTypeOption = formValues?.encryptionTypeOption?.value;

    useInitializeEncryption(encryptionOn, selectedEncryptionType, bucketInfo.kmsKeys, bucketPath, change, kmsKeysOptions, selectedStorageClass);

    return step === 'secondStep' && !isSourceStep ? (
        <div className="bucket-setup">
            <div className="bucket-info">
                <div className="title">
                    Selected S3 bucket:
                </div>
                <div className="bucket-name-container">
                    <div className="bucket-name">
                        <Isvg src={require('./../../../assets/svgs/bucket-icon.svg')}/>
                        <div>{bucketPath}</div>
                    </div>
                    <div className="close-step" onClick={handleClose}>
                        <Isvg src={require('./../../../assets/svgs/x.svg')}/>
                    </div>
                </div>
            </div>
            <div className="setup-container">
                <div className="encryption-container">
                    <div className="title">
                        <div className="key-and-text">
                            <Isvg src={require('./../../../assets/svgs/key-icon.svg')}/>
                            <div>Activate S3 Bucket Encryption</div>
                        </div>
                        <div className="encryption-switch">
                            <Field component={Toggle} name="encryptionOn"/>
                        </div>
                    </div>
                    {encryptionOn && <div>
                        <Field component={SelectField}
                               name="encryptionTypeOption"
                               options={kmsKeysOptions.length === 0
                                   ? _.reject(ENCRYPTION_OPTIONS, option => option.value === ENCRYPTION_TYPES.KMS_EXISTING)
                                   : ENCRYPTION_OPTIONS}
                               label="Encryption type:"/>
                        {encryptionTypeOption === ENCRYPTION_TYPES.KMS_EXISTING && <div>
                            <Field component={SelectField}
                                   label="Encryption Key name"
                                   name="encryptionKeyOption"
                                   options={kmsKeysOptions}
                                   isLoading={!kmsKeysOptions}/>
                        </div>}
                        {encryptionTypeOption === ENCRYPTION_TYPES.KMS_MANUAL && <div>
                            <Field component={InputField}
                                   label="Encryption Key ARN"
                                   name="encryptionKeyManual"
                                   placeholder="Enter an encryption key ARN..."/>
                        </div>}
                    </div>}
                </div>
                <div className="storage-class-container">
                    <div className="title">S3 Storage Class</div>
                    <div>
                        <Field component={SelectField} valueField="value" name="storageClass"
                               options={storageClassOptions}/>
                    </div>
                </div>
            </div>
        </div>) : null;
}