import React from 'react';
import {reduxForm, Field } from 'redux-form';
import {InputField} from "../_common_/forms/forms";
import Validator from 'validatorjs';
import _ from "lodash";
import DialogLayout from '../dialog/DialogLayout';
const indefinite = require('indefinite');
require("./newBucketDialog.scss");

const rules = {
    directoryName: ['required']
};

const validate = (values, props) => {
    const {directoryType} = props;
    const validator = new Validator(values, rules);
    validator.setAttributeNames({directoryName : `${directoryType} name` });
    validator.passes();
    return validator.errors.all();
};


const ManualDirectoryDialog = (props) => {
    const {handleSubmit, onSubmitFunction, closeDialog, directoryType} = props;

    const article = {
        "export": "an",
        "share": "a"
    };

    const directoryName = {
        "export": "export",
        "share": "share"
    };

    const serverName = {
        "export": "NFS",
        "share": "SMB"
    };

    const title = `Add ${_.capitalize(article[directoryType])} ${_.capitalize(directoryName[directoryType])} Manually`;
    return (
        <DialogLayout
            title={title}
            closeDialog={closeDialog}
            onConfirm={handleSubmit(onSubmitFunction)}
            confirmButtonText="Add"
        >
            <div className="row">
                <div className="medium-12 columns">
                    Enter the name of {indefinite(serverName[directoryType])} {directoryName[serverName]} to manually add it.
                    <br/>
                    This step might be necessary if Cloud Sync cannot retrieve {(directoryName[directoryType])}s from the {serverName[directoryType]} server.

                </div>
            </div>
            <div className={"row bucket-name-filed"}>
                <div className={"medium-6 columns"}>
                    <Field component={InputField} name="directoryName" placeholder={`/My${_.capitalize(directoryName[directoryType])}Name`} label={`${_.capitalize(directoryName[directoryType])} name`}/>
                </div>
            </div>
        </DialogLayout>
    )
};

export const ManualDirectoryForm = reduxForm({
    form: 'manual-directory',
    validate
})(ManualDirectoryDialog);
