import React from "react";
import BrokerStatusDisplay from '../syncWizard/BrokerStatusDisplay';
import DataBrokerPropertiesForDialog from './DataBrokerPropertiesForDialog';
import {DEPLOY_STATUS_ERROR, DEPLOY_STATUS_PROGRESS, DEPLOY_STATUS_SUCCESS} from '../../consts';
import PopoverInfo from '../_common_/reactPopover/PopoverInfo';
import Isvg from "react-inlinesvg";
import classNames from "classnames";
import {FM_AGENT_TYPE_ONPREM} from '../../consts';
import "./dataBrokerDialogCard.scss";

const DataBrokerDialogCard = ({handleSectionClick, dataBroker, copyDoneByCloudProvider, displayOnlyHeader, isSingleDb, isActive}) => {
    const {id, name, isWaiting, isFailed, type, ui, deployment} = dataBroker;
    return (
        <div className={classNames("data-broker-dialog-card", {"disabled": isWaiting || isFailed, "single-db": isSingleDb})}>
            <div className="header-area">
                <button type="button" className="title" onClick={()=>{handleSectionClick(id)}}>
                    <div className="name-icon">
                        {(isWaiting || isFailed) && type && ui.type && ui.type.disabledCircledIcon}
                        {!isWaiting && !isFailed && type && ui.type && ui.type.circledIcon}
                        <div className="name" title={name}>{name}</div>
                    </div>
                    <div className="data-broker-info-right">
                        {!copyDoneByCloudProvider && <div className="data-broker-transfer-rate">{ui.transferRate}</div>}
                        <BrokerStatusDisplay {...dataBroker}/>
                        <div className={classNames("chevron", {up: displayOnlyHeader})}>
                            <Isvg src={require("./../../assets/svgs/triangle.svg")}/>
                        </div>
                    </div>
                </button>
            </div>
            <div className={classNames("content-area", {"show-details": isActive})}>
                {!isWaiting && <DataBrokerPropertiesForDialog dataBroker={dataBroker}/>}
                {isWaiting && <DeploymentStatusForDialog deployment={deployment} type={type} providerName={ui.type.providerName}/>}
            </div>

        </div>)
};

export default DataBrokerDialogCard;

const DeploymentStatusForDialog = ({deployment, type, providerName}) => {
    const isOnprem = type === FM_AGENT_TYPE_ONPREM.name;
    return (<div className="card-content-waiting">
            {deployment && (deployment.deployStatus === DEPLOY_STATUS_PROGRESS || deployment.deployStatus === DEPLOY_STATUS_SUCCESS) && <div className="deploy-details">
                <div>This process usually takes around 10 minutes</div>
            </div>}

            {deployment && deployment.deployStatus === DEPLOY_STATUS_ERROR && <div className="deploy-details">
                <div>An error occurred while deploying the Data Broker</div>
                <PopoverInfo>{deployment.errorMessage}</PopoverInfo>
            </div>}

            {!deployment && <div className="deploy-details">
                <div>Waiting for Data Broker creation{isOnprem ? "" : ` in ${providerName}`}.</div>
            </div>}
        </div>
    );
};