import React from "react";
import Isvg from 'react-inlinesvg';
import PopoverError from "../_common_/reactPopover/PopoverError";
import ReactPopover from "../_common_/reactPopover/ReactPopover";
import SyncInfoDialog from "./relationshipCard/SyncInfoDialog";
import DataBrokerGroupInfo from "./DataBrokerGroupInfo"
import {FM_AGENT} from "../../consts";
import TagsPopover from "./../widgets/TagsPopover";
import {createStringFromEndPointObject, createSplitPath} from "./../../utils/helpers"
import {
    getSVGByProtocol, getSVGBySyncStatus,
    getClassBySyncStatus, getFixedProtocol
} from "../../utils/dashboard-utils";
import {
    RESPONSE_STATUS_ABORTED, RESPONSE_STATUS_FAILED,
    RESPONSE_STATUS_PENDING
} from "../../consts";
import {openDialog} from '../dialog/Dialog';
import RelationshipRecommendations from "../RelationshipRecommendations/RelationshipRecommendations";

export default {
    renderRow: row => {
        const syncStatusClass = getClassBySyncStatus(row.ui.status, row.ui.dataBrokers);
        const isSecureRelationship = !!row.encryption;
        const sourceSVG = getSVGByProtocol(getFixedProtocol(row.ui.source), isSecureRelationship);
        const targetSVG = getSVGByProtocol(getFixedProtocol(row.ui.target), isSecureRelationship);
        const syncStatusSVG = getSVGBySyncStatus(row.ui.status, row.ui.dataBrokers);

        const syncTrigger = `${row.ui.isScheduleOn}`;

        const showUnknown = row.ui.showUnknown;
        const statusText = showUnknown ? "Unknown" : row.ui.statusText;
        const showTags = row.ui.tags && row.ui.tags.length > 0;

        const sourceTitle = createStringFromEndPointObject(row.ui.source);
        const splitSourceTitle = createSplitPath(sourceTitle);

        const targetTitle = createStringFromEndPointObject(row.ui.target);
        const splitTargetTitle = createSplitPath(targetTitle);

        const statusClass = (row.ui.status === RESPONSE_STATUS_FAILED || row.ui.status === RESPONSE_STATUS_ABORTED) ? "fail" : (showUnknown ? "unknown" : "");

        const recommendations = row.ui.recommendations;

        const infoPopover = <button disabled={false} className="info"
                                    onClick={(el) => {
                                        openDialog(<SyncInfoDialog className="sync-info-dialog" relationshipId={row.id}
                                                                   calledFrom="dashboard"/>, el.target);
                                    }} key="syncInfo">
            <span><Isvg src={require("./../../assets/svgs/info-circle-icon.svg")}/></span>
        </button>;

        const errorPopover = <PopoverError>{showUnknown ? row.ui.statusText : row.ui.failureMessage}</PopoverError>;

        const pendingPopover = <ReactPopover container={<button className="info" type="button">
                                                <Isvg src={require("./../../assets/svgs/info-circle-icon.svg")}/>
                                             </button>}>The first sync for this relationship is scheduled to start
            at {row.ui.pendingSyncStartTime}.
        </ReactPopover>;

        let popOver;
        if (row.ui.status === RESPONSE_STATUS_FAILED || row.ui.status === RESPONSE_STATUS_ABORTED || showUnknown) popOver = errorPopover;
        else if (row.ui.status === RESPONSE_STATUS_PENDING) popOver = pendingPopover;
        else popOver = infoPopover;

        return (
            <div>
                {/*blank*/}
                <td className="blank"/>
                {/*source*/}
                <td className="endpoint-container" title={sourceTitle}>
                    <div className="endpoint-info">
                        {sourceSVG}
                        <b>{splitSourceTitle[0]}</b>
                        <div className="endpoint-text">{splitSourceTitle.slice(1).join('')}</div>
                    </div>
                </td>
                {/*target*/}
                <td className="endpoint-container" title={targetTitle}>
                    <div className="target-container">
                        <div className="endpoint-info">
                            {targetSVG}
                            <b>{splitTargetTitle[0]}</b>
                            <div className="endpoint-text">{splitTargetTitle[1]}</div>
                        </div>
                        {showTags &&
                        <TagsPopover tags={row.ui.tags} withDiv={true} noTitleSmallResolution={true} leftAdjust={-900} inTable={true}/>}
                    </div>
                </td>
                <td>
                    <DataBrokerGroupInfo dataBrokers={row.ui.dataBrokers}
                                         relationshipId={row.id}
                                         relationshipStatus={row.ui.status}
                                         copyDoneByCloudProvider={row.ui.copyDoneByCloudProvider}/>
                </td>
                <td className="syncTrigger">{syncTrigger}</td>
                <td className={syncStatusClass}>
                    <div className="status-details">
                        <div className={`status-txt ${statusClass}`}>
                            {syncStatusSVG}
                            <span className="cycel-icon">{statusText}</span>
                        </div>
                        <div className={`status-info ${statusClass}`}>
                            {popOver}
                        </div>
                    </div>
                    <div className="remaining-time">
                        {!showUnknown && !row.ui.copyDoneByCloudProvider && row.ui.estimatedTimeText &&
                        <div className="remaining-time" title={row.ui.estimatedTimeText}>
                            {row.ui.estimatedTimeText}
                        </div>
                        }
                    </div>
                </td>
                <td className="notifications">
                    {recommendations[0] && <RelationshipRecommendations recommendations={recommendations} variant='tableView' />}
                </td>
            </div>
        )
    },

    renderHeader: () => (
        <thead>
        <tr>
            <td className="blank" style={{width: "3%"}}/>
            <td style={{width: "21%"}}>Source</td>
            <td style={{width: "21%"}}>Target</td>
            <td className="data-broker" style={{width: "13%"}}>{FM_AGENT}</td>
            <td className="syncTrigger" style={{width: "6%"}}>Schedule</td>
            <td style={{width: "15%", paddingLeft: "10px"}}>Sync Status</td>
            <td style={{width: "18%"}}>Notifications</td>
            <td className="table-menu" style={{width: "3%"}}/>
        </tr>
        </thead>
    )
};