import React from "react";
import classNames from "classnames";
import Isvg from 'react-inlinesvg';
import * as consts from "../../consts";
import PopoverError from "../_common_/reactPopover/PopoverError";
import {FM_AGENT} from "../../consts";
import ReactPopover from "../_common_/reactPopover/ReactPopover";
import {getNextTimeHour} from '../../utils/settings-utils';
import {openDialog} from '../dialog/Dialog';
import SyncInfoDialog from './relationshipCard/SyncInfoDialog';
import _ from 'lodash';

export default {
    renderRow: (row) => {
        const actionStatusClass = classNames({
            "status": true,
            "in-progress": row.status === consts.TIMELINE_ACTION_STATUS_PROGRESS || row.status === consts.TIMELINE_ACTION_STATUS_ABORTING,
            done: row.status === consts.TIMELINE_ACTION_STATUS_DONE,
            failed: (row.status === consts.TIMELINE_ACTION_STATUS_FAILED || row.status === consts.TIMELINE_ACTION_STATUS_INTERRUPTED || row.status === consts.TIMELINE_ACTION_STATUS_ABORTED),
            pending: row.status === consts.TIMELINE_ACTION_STATUS_PENDING
        });

        const pendingSyncStartTime = (row.status === consts.TIMELINE_ACTION_STATUS_PENDING && _.get(row.relationship, 'activateRelationshipAt')) ? getNextTimeHour(row.relationship.activateRelationshipAt) : '';

        let popOver;

        const infoPopover = (row.relationship && row.relationship.activity) ?
            <button disabled={false} className="info-trigger timeline"
                    onClick={(el) => {openDialog(<SyncInfoDialog className="sync-info-dialog" calledFrom="timeline" timelineId={row.id}/>, el.target);}} key="syncInfo">
                <span><Isvg src={require("./../../assets/svgs/info-circle-icon.svg")}/></span>
            </button> : '';

        const errorPopover = <PopoverError style={{transform: "translate(calc(-100% + 37px), 2px)"}}>{row.failureMessage}</PopoverError>;

        const pendingPopover = <ReactPopover container={<button className="timeline" type="button" ><span><Isvg src={require("./../../assets/svgs/info-circle-icon.svg")}/></span></button>}>
                                    The first sync for this relationship is scheduled to start at {pendingSyncStartTime}.
                                </ReactPopover>;

        if (row.status === consts.TIMELINE_ACTION_STATUS_FAILED || row.status === consts.TIMELINE_ACTION_STATUS_INTERRUPTED || row.status === consts.TIMELINE_ACTION_STATUS_ABORTED) popOver = errorPopover;
        else if (row.relationship && row.relationship.activity && (row.status === consts.TIMELINE_ACTION_STATUS_PROGRESS || row.status === consts.TIMELINE_ACTION_STATUS_ABORTING || row.status === consts.TIMELINE_ACTION_STATUS_DONE)) popOver = infoPopover;
        else if (pendingSyncStartTime) popOver = pendingPopover;


        return (
            <div>
                <td className="blank"/>
                <td className="time">{row.createdAt}</td>
                <td className="action" title={row.summary}>{row.summary}</td>
                <td className="data-mover" title={row.dataBrokers}>{row.dataBrokers}</td>
                <td className="source" title={row.source}>{row.source}</td>
                <td className="target" title={row.target}>{row.target}</td>
                <td className={actionStatusClass}>
                    <div>
                        <div>
                            {(row.status === consts.TIMELINE_ACTION_STATUS_PROGRESS || row.status === consts.TIMELINE_ACTION_STATUS_ABORTING) && <span className="status-icon"><Isvg src={require("./../../assets/svgs/rotating-arrows-icon.svg")}/></span>}
                            {row.status === consts.TIMELINE_ACTION_STATUS_DONE && <span className="status-icon"><Isvg src={require("./../../assets/svgs/checkmark-circle-icon.svg")}/></span>}
                            {(row.status === consts.TIMELINE_ACTION_STATUS_FAILED || row.status === consts.TIMELINE_ACTION_STATUS_INTERRUPTED || row.status === consts.TIMELINE_ACTION_STATUS_ABORTED) && <span className="status-icon"><Isvg src={require("./../../assets/svgs/x-circle-icon.svg")}/></span>}
                            {row.status === consts.TIMELINE_ACTION_STATUS_PENDING && <span className="status-icon"><Isvg src={require("./../../assets/svgs/pending-light-grey.svg")}/></span>}
                            {row.status}
                        </div>
                        <div className="info-trigger-fix-location">
                            {popOver}
                        </div>
                    </div>
                </td>
            </div>
        )
    },

    renderHeader: () => (
        <thead>
        <tr>
            <td className="blank"/>
            <td className="time">Time</td>
            <td className="action">Action</td>
            <td className="data-mover">{FM_AGENT}</td>
            <td className="source">Source</td>
            <td className="target">Target</td>
            <td className="status">Status</td>
        </tr>
        </thead>
    )
};