import React, {Component} from 'react';
import CostHeader from "./CostHeader";
import CostTable from "./CostTable";
import TimeSelector from "./TimeSelector";
import {costTime} from "./costUtils";
import LoadingBar from "../../_common_/loadingBar/LoadingBar";
import Isvg from 'react-inlinesvg';
import _ from "lodash";
import moment from "moment";

require("./cost.scss");

class Cost extends Component {
    constructor(props, context){
        super(props, context);
        this.state = {selectedTime: ""};
    }

    timeSelected(value, currentMonth) {
        const {_cost} = this.props;

        const timeString = costTime(value.month, value.year);
        this.setState({selectedTime: timeString});

        if (currentMonth || !_cost || !_cost[timeString])
            this.props.getCost({month: value.month, year: value.year});
    }


    render() {
        const {_cost} = this.props;
        const costByDate = _cost ? _cost[this.state.selectedTime] : null;
        const isLoading = !costByDate || costByDate.inProgress;

        const tableData = costByDate && costByDate.succeeded && costByDate.data ? _.cloneDeep(costByDate.data) : null;
        const isEmpty = tableData && tableData.costArr.length === 0;

        //add the total cost as a last row in the table, add the from since it is used as the key for the animation
        if (tableData && !isEmpty)
            tableData.costArr.push({isLast:true, totalCost: tableData.totalCost, from: moment().valueOf()});
        return (
            <div className="cost">
                <div className="cost-tab-header">
                <h1>Cost</h1>
                <TimeSelector timeSelected={this.timeSelected.bind(this)} {...this.props}></TimeSelector>
                </div>
                {isLoading && <div className="loading">
                    <LoadingBar className="top"></LoadingBar>
                </div>}
                {isEmpty &&
                    <div className="cost-empty">
                        <span><Isvg src={require("../../../assets/svgs/no-cost.svg")}/></span>
                        <p>There Are No Charges Yet</p>
                    </div>
                }
                {!isLoading && !isEmpty && tableData && <CostHeader data={tableData}/>}
                {!isLoading && !isEmpty && tableData && <CostTable tableData={tableData}/>}
            </div>
        )
    }
}

export default Cost