import React, {Component} from 'react';
import Validator from 'validatorjs';
import {Field, reduxForm, SubmissionError} from 'redux-form';
import * as actions from '../../../store/global/action_creators';
import {InputField} from '../../_common_/forms/forms';
import LoadingBar from "../../_common_/loadingBar/LoadingBar";

require("./addBYOLLicense.scss");

const rules = (needNssRegistration) => {
    return needNssRegistration?
    {
        serialNumber: 'required',
        nssUsername: 'required',
        nssPassword: 'required'
    } :
    {
        serialNumber: 'required'
    };
};

const validate = (values, props) => {
    const validator = new Validator(values, rules(props.needNssRegistration));
    validator.setAttributeNames({serialNumber : 'serial number', nssUsername: "NSS user name", nssPassword: 'NSS password' });
    validator.passes();
    return validator.errors.all();
};

class AddBYOLLicense extends Component {
    submit (needNssRegistration, values, dispatch) {
        const {onComplete} = this.props;
        const handleError = (error) => {
            if (error.status !== 401)
                throw new SubmissionError({_error: error.data.message? error.data.message: error.data});

        };
        const addLicense = () => {
            return actions.addBYOLLicense(values)(dispatch)
                .catch(handleError)
                .then(onComplete)
        };
        if (needNssRegistration) {
            return actions.updateNSSCredentials(values)(dispatch)
                .catch(handleError)
                .then(addLicense)
        }
        else return addLicense();
    }

    render() {
        const {handleSubmit, submitting, onComplete, isFirstLicense, needNssRegistration, error} = this.props;
        return (
            <div className="add-license">
                <div>
                    {!isFirstLicense &&
                    <h5>Add License</h5>}

                    <form onSubmit={handleSubmit(this.submit.bind(this, needNssRegistration))} autoComplete="new-password">
                        <div className="license-row">
                            <div className="serial-number-container">
                                <div className="serial-number">
                                    <Field name="serialNumber" component={InputField} label="License Serial Number"
                                           autoComplete="off"
                                           info={{text: "You should have received the license serial number when you purchased the license."}}/>
                                </div>
                                {needNssRegistration && <div className="nss-credentials">
                                    <Field name="nssUsername" component={InputField} label="NSS User Name" autoComplete="new-password"
                                           info={{text: "The NetApp Support Site account must be authorized to access the license serial number. The account must be a NetApp customer-level account (not a guest or temp account)."}}/>
                                    <Field component={InputField} name="nssPassword" type="password" label="NSS Password" autoComplete="new-password"/>
                                </div>}
                            </div>
                           <div className="buttons">
                                <button type="submit" className="button" disabled={submitting}>Add
                                    {submitting && <LoadingBar/>}
                                </button>
                                <button type="button" className="button secondary" onClick={onComplete}>Cancel</button>
                            </div>
                        </div>
                    </form>
                    {error && <div className="error">{error}</div>}
                </div>
            </div>
        )
    }
}

export const AddBYOLLicenseForm = reduxForm({
    form: 'addBYOLLicenseForm',
    validate
})(AddBYOLLicense);