import React from "react";
import Isvg from 'react-inlinesvg';
import PopoverInfo from '../../_common_/reactPopover/PopoverInfo';
import DataBrokerGroupInfo from "../DataBrokerGroupInfo";
import {connect} from "react-redux";
import TagsPopover from "../../widgets/TagsPopover";
import {createStringFromEndPointObject} from "../../../utils/helpers"
import {
    getSVGByProtocol,
    getFixedProtocol
} from '../../../utils/dashboard-utils';
import {
    STORAGE_CLASS_OPTIONS,
    AZURE_BLOB_TIER_OPTIONS
} from '../../../consts';
import _ from 'lodash';
require("./relationshipInfo.scss");

const RelationshipInfo = ({data: {id, encryption, ui: {source, target, isScheduleOn, dataBrokers, tags, copyDoneByCloudProvider, status}}}) => {
    const isSecureRelationship = !!encryption;
    const sourceSVG = getSVGByProtocol(getFixedProtocol(source), isSecureRelationship);
    const targetSVG = getSVGByProtocol(getFixedProtocol(target), isSecureRelationship);
    const syncTrigger = `Schedule [${isScheduleOn}]`;
    const sourceTitle = createStringFromEndPointObject(source);
    const targetTitle = createStringFromEndPointObject(target);

    //calculate the target settings
    const targetSettings = [];
    if (target.protocol === "s3" && !_.isNil(target.s3.encryption)) {
        targetSettings.push("Encryption key was set on target bucket");
    }
    if (target.protocol === "s3" && target.s3.storageClass) {
        targetSettings.push(`Selected Storage Class for target bucket: "${_.find(STORAGE_CLASS_OPTIONS, {value: target.s3.storageClass}).label}"`);
    }
    if (target.protocol === "azure" && target.azure.blobTier) {
        targetSettings.push(`Selected Blob Tier for target blob: "${_.find(AZURE_BLOB_TIER_OPTIONS, {value: target.azure.blobTier}).label}"`);
    }
    const showTargetSettings = targetSettings.length > 0;

    const targetSettingsDiv = (
        <div>
            {targetSettings.map((setting, index) => {
                return <div key={index}>{setting}
                    {index < targetSettings.length - 1 && <hr/>}
                </div>

            })}
        </div>
    );


    return (
        <div>
            <div className="relationship-info">
                <div className="left-pane">
                    <div className="endpoint-container">
                        {sourceSVG}
                        <div className="text">
                            <div className="title">Source</div>
                            <div className="name" title={sourceTitle}>{sourceTitle}</div>
                        </div>
                    </div>
                    <div className="endpoint-container">
                        {targetSVG}
                        <div className="text">
                            <div className="title">Target</div>
                            <div className="data">
                            {showTargetSettings &&
                                <PopoverInfo>{targetSettingsDiv}</PopoverInfo>}
                                <div className="name" title={targetTitle}>{targetTitle}</div>
                            </div>
                        </div>
                    </div>
                    <div className="data-broker">
                        <span className="icon"><Isvg src={require("../../../assets/svgs/data-broker-default.svg")}/></span>
                        <div className="text">
                            <div className="title">{dataBrokers.length === 1 ? dataBrokers[0].ui.type.displayName : "Data Brokers"}</div>
                            <DataBrokerGroupInfo dataBrokers={dataBrokers}
                                                 relationshipId={id}
                                                 relationshipStatus={status}
                                                 copyDoneByCloudProvider={copyDoneByCloudProvider}/>
                        </div>
                    </div>

                </div>
                <div className="relationship-footer">
                    <div className="footer-part">
                        {syncTrigger}
                    </div>
                    <div className="separator">
                        |
                    </div>
                    <div className="footer-part">
                        <TagsPopover withDiv={true} tags={tags || []} leftAdjust={-86} arrowStyle={{left: "46px"}}/>
                    </div>
                </div>
            </div>
        </div>
    )
};

const mapStateToProps = (state) => {
    return {
        _ui:  {...state.syncReducer._ui, ...state.global._ui}
    }
};

export default connect(mapStateToProps)(RelationshipInfo);
