import React from "react";
import Isvg from 'react-inlinesvg';
import {getClassBySyncStatus, getSVGBySyncStatus} from "../../../utils/dashboard-utils";
import {connect} from "react-redux";
import SyncStatistics from './SyncStatistics';
import {
    RESPONSE_STATUS_ABORTED,
    RESPONSE_STATUS_FAILED,
    RESPONSE_STATUS_INTERRUPTED,
    RESPONSE_STATUS_PENDING
} from "../../../consts";
import _ from "lodash";
import * as actionCreators from '../../../store/wizard/action_creators';
import PopoverInfo from '../../_common_/reactPopover/PopoverInfo';
import "./syncInfo.scss";

const SyncInfoHeader = ({data}) => {
    const {
        ui: {
            status, statusText, progress, pendingSyncStartTime, showUnknown, dataBrokers, estimatedTimeText, copyDoneByCloudProvider
        }
    } = data;
    const syncStatusClass = getClassBySyncStatus(status, dataBrokers);
    return (
        <div>
            {!showUnknown && <div className="sync-info-header">
                <div className={"sync-status " + syncStatusClass}>
                    <div className="status-icon">{getSVGBySyncStatus(status, dataBrokers)}</div>
                    <div className="status-info">
                        <div className="status-text">
                            <div>{statusText}</div>
                            {!showUnknown && !_.isNil(progress) && <div className="small-text" title={progress}>{progress}</div>}
                            {status === RESPONSE_STATUS_PENDING && !_.isNil(pendingSyncStartTime) &&
                            <PopoverInfo> The first sync for this relationship is scheduled to start at {pendingSyncStartTime}.</PopoverInfo>}
                        </div>
                        {!copyDoneByCloudProvider && estimatedTimeText && <div className="estimated-time">{estimatedTimeText}  <Isvg src={require("./../../../assets/svgs/time-estimation.svg")}/> </div>}
                    </div>
                </div>
            </div>}
        </div>
    )
};

const SyncInfo = (props) => {
    const {data, calledFrom} = props;
    const { ui: { status, statusText, failureMessage, activityValues, showUnknown }} = data;

    if (!activityValues.scan) return <div/>;

    const showFailureMessage = (status === RESPONSE_STATUS_FAILED || status === RESPONSE_STATUS_INTERRUPTED || status === RESPONSE_STATUS_ABORTED);
    return (
        <div className="sync-info-wide">
            <SyncInfoHeader data={data}/>
            {showFailureMessage &&
            <div className="sync-info-failure">
                <div className="failure-message">
                    {failureMessage}
                </div>
            </div>
            }
            {showUnknown &&
            <div className="sync-info-failure no-border">
                <div className="failure-message">
                    {statusText}
                </div>
            </div>
            }
            {!showUnknown && !showFailureMessage &&
            <SyncStatistics relationship={data} isCardView={true} calledFrom={calledFrom} {...props} />
            }
        </div>
    )
};

const mapStateToProps = (state) => {
    return {
        _downloadLogsRequests: state.syncReducer._downloadLogsRequests
    }
};

const mapDispatchToProps = (dispatch) => {
    return {
        downloadDataBrokerLogs: (groupId, relationshipId) => dispatch(actionCreators.downloadDataBrokerLogs(groupId, relationshipId))
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(SyncInfo)
