import React from "react";
import SyncStatistics from './SyncStatistics';
import {createStringFromEndPointObject, formatActivityValues} from '../../../utils/helpers';
import {getFixedProtocol, getSVGByProtocol} from '../../../utils/dashboard-utils';
import {connect} from "react-redux";
import _ from "lodash";
import * as actionCreators from '../../../store/wizard/action_creators';

require("./syncInfoDialog.scss");


const SyncInfoDialog = (props) => {
    const {closeDialog, relationshipId, timelineId, _ui: {isCmIntegration}} = props;

    //The dialog needs to access the state directly, in order to get updates (when relationship/timeline is updated with new activity values)
    //This is because the dialog is a separate node in the DOM - it is not a child component that gets props updates from parent
    let updatedRelationship;
    if (timelineId) {
        const {_timeline} = props;
        const timelineInStore = _.find(_timeline.data, {id: timelineId});
        updatedRelationship = {...timelineInStore.relationship, group: timelineInStore.group, ui: formatActivityValues(timelineInStore.relationship.activity)};
    } else {
        const {_relationships} = props;
        updatedRelationship = _.find(_relationships.data, {id: relationshipId});
    }

    return (<div className="sync-info-with-title">
        <div className="relationship-info-container">
            <EndPointInfo type="Source" data={updatedRelationship.source} isCmIntegration={isCmIntegration} isSecureRelationship={!!updatedRelationship.encryption}/>
            <EndPointInfo type="Target" data={updatedRelationship.target} isCmIntegration={isCmIntegration} isSecureRelationship={!!updatedRelationship.encryption}/>
        </div>
        <SyncStatistics {...props} relationship={updatedRelationship}/>
        {closeDialog &&
        <div className="bottom-button-middle">
            <div>
                <button className="button secondary" type="button" onClick={closeDialog}>Close</button>
            </div>
        </div>}
    </div>)
};

const mapStateToProps = (state) => {
    return {
        _downloadLogsRequests: state.syncReducer._downloadLogsRequests,
        _ui:  {...state.syncReducer._ui, ...state.global._ui}
    }
};

const mapDispatchToProps = (dispatch) => {
    return {
        downloadDataBrokerLogs: (groupId, relationshipId) => dispatch(actionCreators.downloadDataBrokerLogs(groupId, relationshipId))
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(SyncInfoDialog);

const EndPointInfo = ({type, data, isSecureRelationship}) => {
    const title = createStringFromEndPointObject(data);
    const svg = getSVGByProtocol(getFixedProtocol(data), isSecureRelationship);

    return (
        <div className="endpoint-info" title={title}>
            {svg}
            <div className="info">
                <div className="path-text">{title}</div>
                <div className="small-text">{type}</div>
            </div>
        </div>
    )
};
