import React from 'react';
import Isvg from 'react-inlinesvg';
import classNames from 'classnames';
import OutsideClickHandler from 'react-outside-click-handler';

require('./menuBar.scss');

export const MenuButton = ({ menuButtonClicked, open }) => {
    return (
        <button type="button" className={classNames('menu-button', { active: open })} onClick={() => {
            menuButtonClicked();
        }}>
            <span><Isvg src={require('./../../assets/svgs/support-menu.svg')}/></span>
        </button>);
};

/* Menu.jsx */
export class MenuBar extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            open: false
        };
    }

    menuButtonClicked(forceClose) {
        this.setState({ open: forceClose ? false : !this.state.open });
    }

    render() {
        return (
            <OutsideClickHandler onOutsideClick={() => {
                this.menuButtonClicked(true);
            }}>
                <div className="menu-bar">
                    <MenuButton menuButtonClicked={this.menuButtonClicked.bind(this)} open={this.state.open}/>
                    <div className={classNames('menu-container', { open: this.state.open })} style={{height: this.state.open ? this.props.openHeight : 0}}>
                        {
                            <div className={classNames('menu-list', { open: this.state.open })}>
                                {this.props.children}
                            </div>
                        }
                    </div>
                </div>
            </OutsideClickHandler>);
    }
}
