import React, {Component} from "react"
import {CSSTransition} from "react-transition-group";
import classNames from "classnames";
import OutsideClickHandler from "react-outside-click-handler"
import _ from 'lodash';
import "./rightMenus.scss";

const SlideFromRight = ({component, enter, closeSlider}) => {
    const componentWithClose = React.cloneElement(component, {closeSlider: closeSlider.bind(this)});

    return (
        <CSSTransition in={enter} classNames="slide-from-right" timeout={400} unmountOnExit>
            <div className="slide-from-right-parent">
                <div className={classNames("slide-from-right-component")}>{componentWithClose}</div>
            </div>
        </CSSTransition>
    );
};

const SliderMenu = ({types, typesStatus, menuItemClicked}) => {
    return (
        <div className="menu-options">
            {types.map((type, index) => {
                return <button type="button" key={index} title={type.title}
                               className={classNames("menu-option", type.type, {active: typesStatus[type.type].isOpen})}
                               onClick={() => menuItemClicked(type)}>
                    {type.icon}
                </button>
            })}
        </div>
    );
};

export default class RightMenus extends Component {
    constructor(props) {
        super(props);
        const {sliderContent} = this.props;
        const sliderTypesStatus = {};
        _.each(sliderContent, (content) => {
            sliderTypesStatus[content.type] = {isOpen: false};
        });
        this.state = {sliderTypesStatus};
    }

    closeSlider() {
        const {sliderTypesStatus} = this.state;
        const updatedSliderTypesStatus = _.forIn(sliderTypesStatus, (value) => {
            value.isOpen = false;
        });
        this.setState({sliderTypesStatus: updatedSliderTypesStatus});
    }

    menuItemClicked(sliderType) {
        const {sliderTypesStatus} = this.state;
        const updatedSliderTypesStatus =  _.forIn(sliderTypesStatus, (value, key) => {
            if (key === sliderType.type) {
                value.isOpen = !value.isOpen;
            }
            else value.isOpen = false;
        });
        this.setState({sliderTypesStatus: updatedSliderTypesStatus});
    }

    render() {
        const {sliderContent} = this.props;
        const {sliderTypesStatus} = this.state;
        if (!sliderTypesStatus) return <div/>;
        const showMask = _.find(sliderTypesStatus, {isOpen: true});
        return (
            <OutsideClickHandler onOutsideClick={this.closeSlider.bind(this)}>

                <SliderMenu types={sliderContent} typesStatus={sliderTypesStatus}
                            menuItemClicked={this.menuItemClicked.bind(this)}
                            close={this.closeSlider.bind(this)}/>
                <div className={classNames("slider-mask", {"show-mask":showMask})} onClick={this.closeSlider.bind(this)}/>
                {sliderContent.map((content, index) => {
                    return <SlideFromRight key={index} enter={sliderTypesStatus[content.type].isOpen}
                                           closeSlider={this.closeSlider.bind(this)}
                                           component={content.component}/>
                })}
            </OutsideClickHandler>
        )
    }
}
