import React, {Component} from 'react';
import {SWITCH} from "./../../utils/directives"
import LoadingBar from '../_common_/loadingBar/LoadingBar';
import LoadingIcon from '../_common_/loadingIcon/LoadingIcon';
import {buildUrlParams} from "../../utils/encoders";
import {get} from 'lodash';
import {
    calculateNextStepObj,
    getEndPointObjectForStep,
    getProtocolAndProviderKey
} from '../../utils/sync-utils';
import {isItSourceStep} from '../../utils/reducerUtils';
import {getNextStepComponent} from './../../utils/wizard-utils';

const isFetching = (f, props) => {
    return f && f(props)
};

const isFinished = (f, props) => {
    return f && f(props) && props.children;
};

export default (WrappedComponent, opts = {}) => class extends Component {
    constructor(props){
        super(props);
        const currentStepId = opts.stepId(props);
        const nextStep = calculateNextStepObj(props._wizard, currentStepId);
        const endpointObj = getEndPointObjectForStep(props._wizard.wizardInfo, props.isTargetStepFromSameSourceType, currentStepId);

        this.state = {
            nextStep,
            NextStepComp: nextStep ? getNextStepComponent(nextStep.path) : undefined,
            endpointObj,
            protocolAndProviderKey: endpointObj ? getProtocolAndProviderKey(endpointObj.protocol, endpointObj.provider) : undefined,
            isSourceStep: isItSourceStep(props._wizard.wizardInfo, currentStepId)
        }
    }

    componentDidMount(){
        this.props.updateUrlParams(buildUrlParams(this.props._routing, this.props.match, this.props.location, window.location.href));
        this.props.wizardStepStarted(opts.stepId(this.props));
        if (opts.willMount) {
            opts.willMount({...this.props, ...this.state}, this);
        }
    }

    componentWillUnmount(){
        this.props.wizardStepExited(opts.stepId(this.props));
    }

    render() {
        const {routing : {location: {query}}} = this.props;
        const showWhat = ({match}) => {
            if (isFetching(opts.isFetching, {...this.props, ...this.state})) return "fetching";
            if(!match.isExact || isFinished(opts.canShowNextStep, this.props)) return "next";
            return "current";
        };

        return (
            <SWITCH on={showWhat(this.props)}>
                <div data-when="fetching" className="full-height">
                    <div className="wizard-loading">
                        <LoadingBar/>
                        {opts.loading && <LoadingIcon {...opts.loading({...this.props, ...this.state})} />}
                    </div>
                </div>

                <div data-when="current" className="full-height">
                    <WrappedComponent up={get(query, ["down"])} {...this.props} {...this.state}/>
                </div>
                <div data-when="next" className="full-height">
                    {opts.nextRoutes && opts.nextRoutes({...this.props, ...this.state})}
                </div>

            </SWITCH>
        )
    }
};