import { EC2 } from "@aws-sdk/client-ec2";
import { CloudFormation } from "@aws-sdk/client-cloudformation";
import {SimulatedEC2, SimulatedCloudFormation} from "./SimulatedAwsResources";

export const DEFAULT_REGION = 'us-east-1';

const useMockApi = process.env.REACT_APP_SIMULATED_API === 'true';
const mockBaseApi = process.env.REACT_APP_MOCK_API_URL + '/aws';

const createEC2Client = (credentials, region) => {
    const config = {credentials, region, correctClockSkew: true};
    return useMockApi ? new SimulatedEC2(mockBaseApi) : new EC2(config);
};

const createCloudFormationClient = (credentials, region) => {
    const config = {credentials, region, correctClockSkew: true};
    return useMockApi ? new SimulatedCloudFormation(mockBaseApi) : new CloudFormation(config);
};

// export const getRegions = (credentials) => {
//     const ec2 = createEC2Client({...credentials, region: DEFAULT_REGION});
//     return ec2.describeRegions().promise();
// };

export const getVpcs = (credentials, region) => {
    const ec2 = createEC2Client(credentials, region);
    return ec2.describeVpcs({});
};

export const getSubnets = (credentials, region) => {
    const ec2 = createEC2Client(credentials, region);
    return ec2.describeSubnets({});
};

export const getKeyPairs = (credentials, region) => {
    const ec2 = createEC2Client(credentials, region);
    return ec2.describeKeyPairs({});
};

export const deployTemplate = (credentials, region, params) => {
    const cf = createCloudFormationClient(credentials, region);
    return cf.createStack(params);
};

export const getDeploymentStatus = (credentials, region, stackId) => {
    const cf = createCloudFormationClient(credentials, region);
    return cf.describeStacks({StackName: stackId});

};

export const deleteStack = (credentials, region, stackId) => {
    const cf = createCloudFormationClient(credentials, region);
    return cf.deleteStack({StackName: stackId});
};

export const awsRegions = [
    {'value': 'ap-southeast-1', 'label': 'Asia Pacific | Singapore'},
    {'value': 'ap-southeast-2', 'label': 'Asia Pacific | Sydney'},
    {'value': 'ap-northeast-1', 'label': 'Asia Pacific | Tokyo'},
    {'value': 'ap-northeast-2', 'label': 'Asia Pacific | Seoul'},
    {'value': 'ap-east-1', 'label': 'Asia Pacific | Hong Kong'},
    {'value': 'ca-central-1', 'label': 'Canada | Central'},
    {'value': 'eu-central-1', 'label': 'EU | Frankfurt'},
    {'value': 'eu-west-1', 'label': 'EU | Ireland'},
    {'value': 'eu-west-2', 'label': 'EU | London'},
    {'value': 'eu-west-3', 'label': 'EU | Paris'},
    {'value': 'eu-north-1', 'label': 'EU | Stockholm'},
    {'value': 'ap-south-1', 'label': 'Middle East | Mumbai'},
    {'value': 'sa-east-1', 'label': 'South America | Sao Paulo'},
    {'value': 'us-east-1', 'label': 'US East | N. Virginia'},
    {'value': 'us-east-2', 'label': 'US East | Ohio'},
    {'value': 'us-west-1', 'label': 'US West | N. California'},
    {'value': 'us-west-2', 'label': 'US West | Oregon'},
    {'value': 'us-gov-west-1', 'label': 'US West Government | N. California'}
];
