import * as azureService from './azure.api.service';

const DELETE_RESOURCES_TIMEOUT = 15 * 1000;

export const rollback = async (deployDetails) => {
    const {isExistingResourceGroup, subscriptionId, resourceGroupName, deploymentName} = deployDetails;
    try {
        //cancel is needed in case the user wants to delete an on-going deployment (not failed)
        await azureService.cancelDeployment(subscriptionId, resourceGroupName, deploymentName);
    }
    catch {
        // eslint-disable-next-line
        console.log('deployment could not be cancelled');
    }
    const rollbackFunction = isExistingResourceGroup ? deleteVmAndDescending : deleteEntireResourceGroup;
    return rollbackFunction(deployDetails);
};

const deleteEntireResourceGroup = async ({subscriptionId, resourceGroupName}) => {
    return azureService.deleteResourceGroup(subscriptionId, resourceGroupName);
};

const deleteVmAndDescending = async ({subscriptionId, resourceGroupName, properties}) => {
    const vmName = properties.parameters.virtualMachineName.value;
    try {
        const vm = await azureService.getVm(subscriptionId, resourceGroupName, vmName);
        const diskName = vm.properties.storageProfile.osDisk.name;
        let timeout;

        await azureService.deleteVM(subscriptionId, resourceGroupName, vmName);

        //Polling on the vm, to check if it was deleted
        const interval = setInterval(async () => {
            try {
                await azureService.getVm(subscriptionId, resourceGroupName, vmName);
            }
            catch {
                //If vm doesn't exists -> it was deleted successfully
                clearTimeout(timeout);
                clearInterval(interval);
                return await deleteOtherResources(subscriptionId, resourceGroupName, vmName, diskName);
            }
        }, 30* 1000);

        timeout = setTimeout(async () => {
            //even if vm is not deleted yet, just go on to delete the rest of the resources
            clearInterval(interval);
            return await deleteOtherResources(subscriptionId, resourceGroupName, vmName, diskName);
        },5 * 60 * 1000)
    }

    catch {
        //vm doesn't exist
        return await deleteOtherResources(subscriptionId, resourceGroupName, vmName);
    }
};

const deleteOtherResources = async (subscriptionId, resourceGroupName, vmName, diskName) => {
    let timeout;

    //Should retry in case of error, to cover cases that the error is because the resource is associated to a resource that is not deleted yet
    //for example, NIC should be deleted before PIP/NSG can be deleted
    //note: in case a resource doesn't exist, Azure api returns nothing (no error)
    const interval = setInterval(async () => {
        try {
            await azureService.deleteNetworkInterface(subscriptionId, resourceGroupName, `${vmName}-nic`);
            if (diskName) await azureService.deleteDisk(subscriptionId, resourceGroupName, diskName);
            await azureService.deletePublicIP(subscriptionId, resourceGroupName, `${vmName}-pip`);
            await azureService.deleteSecurityGroup(subscriptionId, resourceGroupName, `${vmName}-nsg`);
            clearInterval(interval);
            clearTimeout(timeout);
        }
        catch (e) {
            // eslint-disable-next-line no-console
            console.log(e.data.error.message);
        }
    }, 5000);
    timeout = setTimeout(() => {
        clearInterval(interval);
    }, DELETE_RESOURCES_TIMEOUT);
};