import axios from 'axios';
import {store} from '../store/store';

const axiosInstance = axios.create({
    baseURL: process.env.REACT_APP_PORTAL_API_BASE_URL + "/cvs"
});

const isSimulator = process.env.REACT_APP_USE_PORTAL_SIMULATOR === "true";

const extractData = (response) => {
    return response.data;
};

const getHeaders = () => {
    const accessToken = store.getState().global.auth.accessToken;
    return isSimulator
    ? { headers: { Authorization: accessToken, "X-Simulator": "true" } }
    : { headers: { Authorization: accessToken } };
};

export default {
    getWorkingEnvironments: (accountId) => {
        return axiosInstance.get(`/accounts/${accountId}/working-environments`, getHeaders()).then(extractData);
    },
    getAnfVolumes: (accountId, credentialsId) => {
        return axiosInstance.get(`/azure/accounts/${accountId}/credentials/${credentialsId}/volumes`, getHeaders()).then(extractData);
    },
};