import _ from "lodash";
import {parse} from 'query-string';

export const encodeAll = (text) => {
    if (text) {
        const internalEncoding = text.replace(/%/g, "%25").replace(/\//g, "%2F").replace(/\./g, '%2E').replace(/-/g, "%2D").replace(/\(/g, "%2C");
        const encodedComponent = encodeURIComponent(internalEncoding);
        return encodedComponent.replace(/%/g, "---"); //replacing the precent to prevent the default encoding on the way back which ruined the url
    }
    return text;
};

export const decodeAll = (text) => {
    if (text) {
        //now need to decode all the way back since can't rely on the automatic decoding
        const withPrecent = text.replace(/---/g, "%");
        const decodedURI = decodeURIComponent(withPrecent);
        return decodedURI.replace(/%25/g, "%").replace(/%2F/g, "/").replace(/%2E/g, ".").replace(/%2D/g, "-").replace(/%2C/g, "(");
    }
    return text;
};

export const clearDoubleSlash = (text) => {
    return text.replace("//", "/");
};

export const removeStartingAndEndingSlash = (path) => {
    if (_.isEmpty(path)) return path;
    const startsWithSlash = path[0] === "/";
    const endsWithSlash = path[path.length - 1] === "/";
    return path.substring(startsWithSlash ? 1 : 0, endsWithSlash ? path.length - 1 : path.length);
};

//path must always start with slash and end with no slash
export const fixPath = (path, keepSlash = false) => {
    if (_.isEmpty(path)) return path;
    const pathWithoutTrailingSlashes = path.replace(/^(?:\/)+/, "");
    // console.log(`%c fixPath path ${path} pathWithoutSlashes@ ${pathWithoutTrailingSlashes}`, "font-weight: bold;");
    return _.isEmpty(pathWithoutTrailingSlashes) && !keepSlash ? pathWithoutTrailingSlashes : "/" + pathWithoutTrailingSlashes;
};

export const buildUrlParams = (_routing, match, propsLocation, href) => {
    let location = propsLocation;
    location.query = parse(location.search);
    const decodedParams = _.each(match.params, (param) => decodeAll(param));
    // console.log(`%c================ encoder buildUrlParams\n href: ${href}\n propsLocation: ${JSON.stringify(propsLocation)}\n match: ${JSON.stringify(match)}\ndecodedParams: ${JSON.stringify(decodedParams)}\n=================`, 'font-weight:bold;color:blue');

    return {
        params: match.params,
        href,
        location,
        decodedParams
    }
};