import _ from "lodash";
import {removeStartingAndEndingSlash} from "./encoders";
import {getWizardSelectedParams} from "./sync-utils"
import {SERVER_TYPES} from '../consts';

export function getPropFromState(state, key, defaultValue) {
    return state.syncReducer[key] ? state.syncReducer[key] : defaultValue;
}

export const buildErrorsList = (state) => {
    const errorsMap = state.syncReducer._generalErrors._errorsMap;
    return {
        _errors: _.orderBy(_.values(errorsMap), "time", "desc"),
        _errorsPanelOpen: state.syncReducer._generalErrors._errorsPanelOpen,
        _errorsPanelSize: state.syncReducer._generalErrors._errorsPanelSize
    }
};

export const buildServersList = (state) => {
    return Object.values(SERVER_TYPES).reduce((res, k) => {
            res[k] = (state.syncReducer._servers && state.syncReducer._servers[k]) ? state.syncReducer._servers[k] : {inProgress: true};
            return res;
        }, {});
};

export const getWizardParamsFromUrlParams = (fullState, ownProps) => {
    const {syncReducer: state} = fullState;
    if (!state._wizard || !ownProps.match || !ownProps.match.params) return state._wizard;

    const {stepInfoById, currentStep} = state._wizard;
    //remove beginning slash and ending slash
    const currentPath = removeStartingAndEndingSlash(ownProps.location.pathname);

    const currentPathSegments = currentPath.split("/");

    const currentStepPath = _.get(stepInfoById[currentStep], 'path');
    const currentPathIndex = currentPathSegments.indexOf(currentStepPath);
    const newPath = currentPathIndex > -1 ? currentPathSegments.slice(0, currentPathIndex + 1).join("/") : currentPath;

    const nextStep = (suffix, history) => {
        history.push(`/${newPath}${suffix}`);
    };
    const {urlParams} = state._wizard;
    //build the wizard params out of the current url params, or if not exist, with params kept in wizard.urlParams - to allow filling the wizard when moving forward with all that was already selected
    const wizardParams = ({...urlParams, ...ownProps.match.params});
    const selectedWizardParams = getWizardSelectedParams(state, wizardParams);

    return state._wizard.set("nextStep", nextStep).updateIn(["selectedWizardParams"], currentParams => {
        return ({...currentParams, ...selectedWizardParams});
    });
};


// export default function (state, ownProps) {
//     return fillWizardData({
//         auth: state.global.auth || {succeeded: false, inProgress: true, failed: false},
//         _servers: buildServersList(state),
//         _azureStorageAccounts: getPropFromState(state, "_azureStorageAccounts", {inProgress: true}),
//         _timeline: state.global._timeline,
//         _dataBrokers: getPropFromState(state, "_dataBrokers", {inProgress: true}),
//         _licenseSettings: state.global._licenseSettings,
//         _licenses: state.global._licenses,
//         _showExports: getPropFromState(state, "_showExports", {}),
//         _showShares: getPropFromState(state, "_showShares", {}),
//         _showBuckets: getPropFromState(state, "_showBuckets", {}),
//         _showAzureBlobContainers: getPropFromState(state, "_showAzureBlobContainers", {}),
//         _showS3BasedBuckets: getPropFromState(state, "_showS3BasedBuckets", {}),
//         _showGCPBuckets: getPropFromState(state, "_showGCPBuckets", {}),
//         _relationships: getPropFromState(state, "_relationships", {inProgress: true, firstTime: true}),
//         _wizard: getPropFromState(state, "_wizard", null),
//         _ui: {...state.syncReducer._ui, ...state.global._ui},
//         _generalErrors: buildErrorsList(state),
//         ownProps: ownProps,
//         _routing: getPropFromState(state, "_routing", {}),
//         _downloadLogsRequests: getPropFromState(state, "_downloadLogsRequests", {}),
//         _accounts: state.global._accounts,
//         _accountInfo: state.global._accountInfo,
//         _notifications: state.global._notifications,
//         _deployments: state.deploy.deployments,
//         _cmIntegration: state.global._cmIntegration,
//         _cvsWorkingEnvironments: getPropFromState(state, "_cvsWorkingEnvironments", {}),
//         _anfVolumes:  getPropFromState(state, "_anfVolumes", {})
//     }, ownProps)
// }