import jsdom from 'jsdom';
import configureMockStore from 'redux-mock-store'
import thunk from 'redux-thunk'
import axios from 'axios';

const middlewares = [ thunk ];
export const mockStore = configureMockStore(middlewares);

export const initTests = () => {
    const {JSDOM} = jsdom;
    const dom = new JSDOM('<!doctype html><html><body></body></html>');
    const win = dom.window;
    const doc = dom.window.document;

    global.document = doc;
    global.window = win;

    Object.keys(window).forEach((key) => {
        if (!(key in global)) {
            global[key] = window[key];
        }
    });

    axios.defaults.baseURL = 'http://localhost/api';


    const mockLocalStorage = () => {
        const storage = {};
        return {
            setItem: (key, value) => {
                storage[key] = value;
            },
            getItem: (key) => {
                return storage[key] ? storage[key] : null;
            },
            removeItem: (key) => {
                delete storage[key];
            }
        }
    };
    const mockAuth = () => {
        return {
            logout: () => {},
            loginRedirect: () => {}
        }
    };

    global.window.auth = mockAuth();
    global.window.localStorage = mockLocalStorage();
    global.window.sessionStorage = mockLocalStorage();
};

initTests();


